// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: proto/alarm/v1/stream.proto
// Protobuf C++ Version: 7.35.1

#include "proto/alarm/v1/stream.pb.h"

#include <algorithm>
#include <type_traits>
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/generated_message_tctable_impl.h"
#include "google/protobuf/internal_visibility.h"
#include "google/protobuf/extension_set.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/wire_format_lite.h"
#include "google/protobuf/descriptor.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/reflection_ops.h"
#include "google/protobuf/wire_format.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"
PROTOBUF_PRAGMA_INIT_SEG
namespace _pb = ::google::protobuf;
namespace _pbi = ::google::protobuf::internal;
namespace _fl = ::google::protobuf::internal::field_layout;
#ifdef PROTOBUF_MESSAGE_GLOBALS
namespace {
PROTOBUF_CONSTINIT ::google::protobuf::internal::ReflectionData
    file_reflection_data[] = {
        // ::alarms::v1::SendAlarmLogHealth
        {&::_pbi::kDescriptorMethods, &::descriptor_table_proto_2falarm_2fv1_2fstream_2eproto, /* tracker*/ nullptr,},
        // ::alarms::v1::AlarmLogHealth
        {&::_pbi::kDescriptorMethods, &::descriptor_table_proto_2falarm_2fv1_2fstream_2eproto, /* tracker*/ nullptr,},
        // ::alarms::v1::LogEntries
        {&::_pbi::kDescriptorMethods, &::descriptor_table_proto_2falarm_2fv1_2fstream_2eproto, /* tracker*/ nullptr,},
        // ::alarms::v1::StartAlarmStreaming
        {&::_pbi::kDescriptorMethods, &::descriptor_table_proto_2falarm_2fv1_2fstream_2eproto, /* tracker*/ nullptr,},
        // ::alarms::v1::SendAlarmCheckpoint
        {&::_pbi::kDescriptorMethods, &::descriptor_table_proto_2falarm_2fv1_2fstream_2eproto, /* tracker*/ nullptr,},
        // ::alarms::v1::AlarmCheckpoint
        {&::_pbi::kDescriptorMethods, &::descriptor_table_proto_2falarm_2fv1_2fstream_2eproto, /* tracker*/ nullptr,},
        // ::alarms::v1::AlarmLogEntry
        {&::_pbi::kDescriptorMethods, &::descriptor_table_proto_2falarm_2fv1_2fstream_2eproto, /* tracker*/ nullptr,},
        // ::alarms::v1::SendAlarmSnapshot
        {&::_pbi::kDescriptorMethods, &::descriptor_table_proto_2falarm_2fv1_2fstream_2eproto, /* tracker*/ nullptr,},
        // ::alarms::v1::AlarmSnapshot
        {&::_pbi::kDescriptorMethods, &::descriptor_table_proto_2falarm_2fv1_2fstream_2eproto, /* tracker*/ nullptr,},
};
}  // namespace
#endif
namespace alarms {
namespace v1 {
class StartAlarmStreaming::_Internal {
 public:
  using HasBits = decltype(::std::declval<StartAlarmStreaming>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(StartAlarmStreaming, _impl_._has_bits_);
};

constexpr StartAlarmStreaming::ParseTableT_ StartAlarmStreaming::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(StartAlarmStreaming, _impl_._has_bits_),
      0, // no _extensions_
      5, 56,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967264,  // skipmap
      offsetof(ParseTableT_, field_entries),
      5,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::alarms::v1::StartAlarmStreaming>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // string node_id = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(StartAlarmStreaming, _impl_.node_id_)}},
      // uint64 batch_id = 2 [deprecated = true];
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(StartAlarmStreaming, _impl_.batch_id_), 1>(),
       {16, 1, 0,
        PROTOBUF_FIELD_OFFSET(StartAlarmStreaming, _impl_.batch_id_)}},
      // uint64 start_sequnce_id = 3 [deprecated = true];
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(StartAlarmStreaming, _impl_.start_sequnce_id_), 2>(),
       {24, 2, 0,
        PROTOBUF_FIELD_OFFSET(StartAlarmStreaming, _impl_.start_sequnce_id_)}},
      // bool resets = 4;
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(StartAlarmStreaming, _impl_.resets_), 4>(),
       {32, 4, 0,
        PROTOBUF_FIELD_OFFSET(StartAlarmStreaming, _impl_.resets_)}},
      // uint64 version = 5;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(StartAlarmStreaming, _impl_.version_), 3>(),
       {40, 3, 0,
        PROTOBUF_FIELD_OFFSET(StartAlarmStreaming, _impl_.version_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // string node_id = 1;
      {PROTOBUF_FIELD_OFFSET(StartAlarmStreaming, _impl_.node_id_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // uint64 batch_id = 2 [deprecated = true];
      {PROTOBUF_FIELD_OFFSET(StartAlarmStreaming, _impl_.batch_id_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
      // uint64 start_sequnce_id = 3 [deprecated = true];
      {PROTOBUF_FIELD_OFFSET(StartAlarmStreaming, _impl_.start_sequnce_id_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
      // bool resets = 4;
      {PROTOBUF_FIELD_OFFSET(StartAlarmStreaming, _impl_.resets_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // uint64 version = 5;
      {PROTOBUF_FIELD_OFFSET(StartAlarmStreaming, _impl_.version_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    }},
    // no aux_entries
    {{
      "\35\7\0\0\0\0\0\0"
      "alarms.v1.StartAlarmStreaming"
      "node_id"
    }},
  };
}


inline constexpr StartAlarmStreaming::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        node_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        batch_id_{::uint64_t{0u}},
        start_sequnce_id_{::uint64_t{0u}},
        version_{::uint64_t{0u}},
        resets_{false} {}

template <typename>
constexpr StartAlarmStreaming::StartAlarmStreaming(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL StartAlarmStreaming::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) StartAlarmStreaming(arena);
}
constexpr auto StartAlarmStreaming::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(StartAlarmStreaming), alignof(StartAlarmStreaming));
}
constexpr auto StartAlarmStreaming::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &StartAlarmStreaming::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<StartAlarmStreaming>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &StartAlarmStreaming::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<StartAlarmStreaming>(), &StartAlarmStreaming::ByteSizeLong,
              &StartAlarmStreaming::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(StartAlarmStreaming, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[3],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_proto_2falarm_2fv1_2fstream_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct StartAlarmStreamingGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr StartAlarmStreamingGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 StartAlarmStreaming_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(StartAlarmStreaming::InternalGenerateClassData_(
            _default, &StartAlarmStreaming_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<StartAlarmStreaming>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~StartAlarmStreamingGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) StartAlarmStreaming _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<StartAlarmStreaming>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(StartAlarmStreamingGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST StartAlarmStreamingGlobalsTypeInternal StartAlarmStreaming_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* StartAlarmStreaming_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return StartAlarmStreaming_globals_.GetClassData();
#else
  return StartAlarmStreaming_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class SendAlarmSnapshot::_Internal {
 public:
  using HasBits = decltype(::std::declval<SendAlarmSnapshot>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(SendAlarmSnapshot, _impl_._has_bits_);
};

constexpr SendAlarmSnapshot::ParseTableT_ SendAlarmSnapshot::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(SendAlarmSnapshot, _impl_._has_bits_),
      0, // no _extensions_
      5, 56,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967264,  // skipmap
      offsetof(ParseTableT_, field_entries),
      5,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::alarms::v1::SendAlarmSnapshot>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // string node_id = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(SendAlarmSnapshot, _impl_.node_id_)}},
      // string claim_id = 2;
      {::_pbi::TcParser::FastUS1,
       {18, 1, 0,
        PROTOBUF_FIELD_OFFSET(SendAlarmSnapshot, _impl_.claim_id_)}},
      // uint64 snapshot_id = 3 [deprecated = true];
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(SendAlarmSnapshot, _impl_.snapshot_id_), 3>(),
       {24, 3, 0,
        PROTOBUF_FIELD_OFFSET(SendAlarmSnapshot, _impl_.snapshot_id_)}},
      // uint64 sequence_id = 4 [deprecated = true];
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(SendAlarmSnapshot, _impl_.sequence_id_), 4>(),
       {32, 4, 0,
        PROTOBUF_FIELD_OFFSET(SendAlarmSnapshot, _impl_.sequence_id_)}},
      // string snapshot_uuid = 5;
      {::_pbi::TcParser::FastUS1,
       {42, 2, 0,
        PROTOBUF_FIELD_OFFSET(SendAlarmSnapshot, _impl_.snapshot_uuid_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // string node_id = 1;
      {PROTOBUF_FIELD_OFFSET(SendAlarmSnapshot, _impl_.node_id_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string claim_id = 2;
      {PROTOBUF_FIELD_OFFSET(SendAlarmSnapshot, _impl_.claim_id_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // uint64 snapshot_id = 3 [deprecated = true];
      {PROTOBUF_FIELD_OFFSET(SendAlarmSnapshot, _impl_.snapshot_id_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
      // uint64 sequence_id = 4 [deprecated = true];
      {PROTOBUF_FIELD_OFFSET(SendAlarmSnapshot, _impl_.sequence_id_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
      // string snapshot_uuid = 5;
      {PROTOBUF_FIELD_OFFSET(SendAlarmSnapshot, _impl_.snapshot_uuid_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    }},
    // no aux_entries
    {{
      "\33\7\10\0\0\15\0\0"
      "alarms.v1.SendAlarmSnapshot"
      "node_id"
      "claim_id"
      "snapshot_uuid"
    }},
  };
}


inline constexpr SendAlarmSnapshot::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        node_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        claim_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        snapshot_uuid_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        snapshot_id_{::uint64_t{0u}},
        sequence_id_{::uint64_t{0u}} {}

template <typename>
constexpr SendAlarmSnapshot::SendAlarmSnapshot(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL SendAlarmSnapshot::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) SendAlarmSnapshot(arena);
}
constexpr auto SendAlarmSnapshot::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(SendAlarmSnapshot), alignof(SendAlarmSnapshot));
}
constexpr auto SendAlarmSnapshot::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &SendAlarmSnapshot::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<SendAlarmSnapshot>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &SendAlarmSnapshot::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<SendAlarmSnapshot>(), &SendAlarmSnapshot::ByteSizeLong,
              &SendAlarmSnapshot::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(SendAlarmSnapshot, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[7],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_proto_2falarm_2fv1_2fstream_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct SendAlarmSnapshotGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr SendAlarmSnapshotGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 SendAlarmSnapshot_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(SendAlarmSnapshot::InternalGenerateClassData_(
            _default, &SendAlarmSnapshot_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<SendAlarmSnapshot>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~SendAlarmSnapshotGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) SendAlarmSnapshot _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<SendAlarmSnapshot>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(SendAlarmSnapshotGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST SendAlarmSnapshotGlobalsTypeInternal SendAlarmSnapshot_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* SendAlarmSnapshot_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return SendAlarmSnapshot_globals_.GetClassData();
#else
  return SendAlarmSnapshot_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class SendAlarmLogHealth::_Internal {
 public:
  using HasBits = decltype(::std::declval<SendAlarmLogHealth>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(SendAlarmLogHealth, _impl_._has_bits_);
};

constexpr SendAlarmLogHealth::ParseTableT_ SendAlarmLogHealth::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(SendAlarmLogHealth, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::alarms::v1::SendAlarmLogHealth>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // string node_id = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(SendAlarmLogHealth, _impl_.node_id_)}},
    }}, {{
      65535, 65535
    }}, {{
      // string node_id = 1;
      {PROTOBUF_FIELD_OFFSET(SendAlarmLogHealth, _impl_.node_id_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    }},
    // no aux_entries
    {{
      "\34\7\0\0\0\0\0\0"
      "alarms.v1.SendAlarmLogHealth"
      "node_id"
    }},
  };
}


inline constexpr SendAlarmLogHealth::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        node_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()) {}

template <typename>
constexpr SendAlarmLogHealth::SendAlarmLogHealth(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL SendAlarmLogHealth::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) SendAlarmLogHealth(arena);
}
constexpr auto SendAlarmLogHealth::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(SendAlarmLogHealth), alignof(SendAlarmLogHealth));
}
constexpr auto SendAlarmLogHealth::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &SendAlarmLogHealth::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<SendAlarmLogHealth>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &SendAlarmLogHealth::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<SendAlarmLogHealth>(), &SendAlarmLogHealth::ByteSizeLong,
              &SendAlarmLogHealth::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(SendAlarmLogHealth, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[0],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_proto_2falarm_2fv1_2fstream_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct SendAlarmLogHealthGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr SendAlarmLogHealthGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 SendAlarmLogHealth_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(SendAlarmLogHealth::InternalGenerateClassData_(
            _default, &SendAlarmLogHealth_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<SendAlarmLogHealth>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~SendAlarmLogHealthGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) SendAlarmLogHealth _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<SendAlarmLogHealth>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(SendAlarmLogHealthGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST SendAlarmLogHealthGlobalsTypeInternal SendAlarmLogHealth_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* SendAlarmLogHealth_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return SendAlarmLogHealth_globals_.GetClassData();
#else
  return SendAlarmLogHealth_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class SendAlarmCheckpoint::_Internal {
 public:
  using HasBits = decltype(::std::declval<SendAlarmCheckpoint>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(SendAlarmCheckpoint, _impl_._has_bits_);
};

constexpr SendAlarmCheckpoint::ParseTableT_ SendAlarmCheckpoint::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(SendAlarmCheckpoint, _impl_._has_bits_),
      0, // no _extensions_
      3, 24,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967288,  // skipmap
      offsetof(ParseTableT_, field_entries),
      3,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::alarms::v1::SendAlarmCheckpoint>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // string node_id = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(SendAlarmCheckpoint, _impl_.node_id_)}},
      // string claim_id = 2;
      {::_pbi::TcParser::FastUS1,
       {18, 1, 0,
        PROTOBUF_FIELD_OFFSET(SendAlarmCheckpoint, _impl_.claim_id_)}},
      // uint64 version = 3;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(SendAlarmCheckpoint, _impl_.version_), 2>(),
       {24, 2, 0,
        PROTOBUF_FIELD_OFFSET(SendAlarmCheckpoint, _impl_.version_)}},
    }}, {{
      65535, 65535
    }}, {{
      // string node_id = 1;
      {PROTOBUF_FIELD_OFFSET(SendAlarmCheckpoint, _impl_.node_id_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string claim_id = 2;
      {PROTOBUF_FIELD_OFFSET(SendAlarmCheckpoint, _impl_.claim_id_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // uint64 version = 3;
      {PROTOBUF_FIELD_OFFSET(SendAlarmCheckpoint, _impl_.version_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    }},
    // no aux_entries
    {{
      "\35\7\10\0\0\0\0\0"
      "alarms.v1.SendAlarmCheckpoint"
      "node_id"
      "claim_id"
    }},
  };
}


inline constexpr SendAlarmCheckpoint::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        node_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        claim_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        version_{::uint64_t{0u}} {}

template <typename>
constexpr SendAlarmCheckpoint::SendAlarmCheckpoint(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL SendAlarmCheckpoint::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) SendAlarmCheckpoint(arena);
}
constexpr auto SendAlarmCheckpoint::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(SendAlarmCheckpoint), alignof(SendAlarmCheckpoint));
}
constexpr auto SendAlarmCheckpoint::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &SendAlarmCheckpoint::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<SendAlarmCheckpoint>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &SendAlarmCheckpoint::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<SendAlarmCheckpoint>(), &SendAlarmCheckpoint::ByteSizeLong,
              &SendAlarmCheckpoint::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(SendAlarmCheckpoint, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[4],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_proto_2falarm_2fv1_2fstream_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct SendAlarmCheckpointGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr SendAlarmCheckpointGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 SendAlarmCheckpoint_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(SendAlarmCheckpoint::InternalGenerateClassData_(
            _default, &SendAlarmCheckpoint_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<SendAlarmCheckpoint>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~SendAlarmCheckpointGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) SendAlarmCheckpoint _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<SendAlarmCheckpoint>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(SendAlarmCheckpointGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST SendAlarmCheckpointGlobalsTypeInternal SendAlarmCheckpoint_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* SendAlarmCheckpoint_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return SendAlarmCheckpoint_globals_.GetClassData();
#else
  return SendAlarmCheckpoint_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class AlarmLogEntry::_Internal {
 public:
  using HasBits = decltype(::std::declval<AlarmLogEntry>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_._has_bits_);
};

constexpr AlarmLogEntry::ParseTableT_ AlarmLogEntry::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_._has_bits_),
      0, // no _extensions_
      34, 248,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      0,  // skipmap
      offsetof(ParseTableT_, field_entries),
      34,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::alarms::v1::AlarmLogEntry>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // string node_id = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.node_id_)}},
      // string claim_id = 2;
      {::_pbi::TcParser::FastUS1,
       {18, 1, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.claim_id_)}},
      // string chart = 3;
      {::_pbi::TcParser::FastUS1,
       {26, 2, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.chart_)}},
      // string name = 4;
      {::_pbi::TcParser::FastUS1,
       {34, 3, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.name_)}},
      // string family = 5 [deprecated = true];
      {::_pbi::TcParser::FastUS1,
       {42, 4, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.family_)}},
      // uint64 batch_id = 6 [deprecated = true];
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(AlarmLogEntry, _impl_.batch_id_), 15>(),
       {48, 15, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.batch_id_)}},
      // uint64 sequence_id = 7 [deprecated = true];
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(AlarmLogEntry, _impl_.sequence_id_), 16>(),
       {56, 16, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.sequence_id_)}},
      // uint64 when = 8;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(AlarmLogEntry, _impl_.when_), 17>(),
       {64, 17, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.when_)}},
      // string config_hash = 9;
      {::_pbi::TcParser::FastUS1,
       {74, 5, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.config_hash_)}},
      // int32 utc_offset = 10;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(AlarmLogEntry, _impl_.utc_offset_), 18>(),
       {80, 18, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.utc_offset_)}},
      // string timezone = 11;
      {::_pbi::TcParser::FastUS1,
       {90, 6, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.timezone_)}},
      // string exec_path = 12;
      {::_pbi::TcParser::FastUS1,
       {98, 7, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.exec_path_)}},
      // string conf_source = 13;
      {::_pbi::TcParser::FastUS1,
       {106, 8, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.conf_source_)}},
      // string command = 14;
      {::_pbi::TcParser::FastUS1,
       {114, 9, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.command_)}},
      // uint32 duration = 15;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(AlarmLogEntry, _impl_.duration_), 19>(),
       {120, 19, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.duration_)}},
      // uint32 non_clear_duration = 16;
      {::_pbi::TcParser::FastV32S2,
       {384, 20, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.non_clear_duration_)}},
      // .alarms.v1.AlarmStatus status = 17;
      {::_pbi::TcParser::FastV32S2,
       {392, 21, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.status_)}},
      // .alarms.v1.AlarmStatus old_status = 18;
      {::_pbi::TcParser::FastV32S2,
       {400, 25, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.old_status_)}},
      // uint64 delay = 19;
      {::_pbi::TcParser::FastV64S2,
       {408, 22, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.delay_)}},
      // uint64 delay_up_to_timestamp = 20;
      {::_pbi::TcParser::FastV64S2,
       {416, 23, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.delay_up_to_timestamp_)}},
      // uint64 last_repeat = 21;
      {::_pbi::TcParser::FastV64S2,
       {424, 24, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.last_repeat_)}},
      // bool silenced = 22;
      {::_pbi::TcParser::FastV8S2,
       {432, 26, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.silenced_)}},
      // string value_string = 23;
      {::_pbi::TcParser::FastUS2,
       {442, 10, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.value_string_)}},
      // string old_value_string = 24;
      {::_pbi::TcParser::FastUS2,
       {450, 11, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.old_value_string_)}},
      // double value = 25;
      {::_pbi::TcParser::FastF64S2,
       {457, 28, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.value_)}},
      // double old_value = 26;
      {::_pbi::TcParser::FastF64S2,
       {465, 29, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.old_value_)}},
      // bool updated = 27;
      {::_pbi::TcParser::FastV8S2,
       {472, 27, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.updated_)}},
      // string rendered_info = 28;
      {::_pbi::TcParser::FastUS2,
       {482, 12, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.rendered_info_)}},
      // string chart_context = 29;
      {::_pbi::TcParser::FastUS2,
       {490, 13, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.chart_context_)}},
      // uint64 event_id = 30;
      {::_pbi::TcParser::FastV64S2,
       {496, 30, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.event_id_)}},
      // string transition_id = 31;
      {::_pbi::TcParser::FastUS2,
       {506, 14, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.transition_id_)}},
    }}, {{
      33, 0, 1,
      65532, 32,
      65535, 65535
    }}, {{
      // string node_id = 1;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.node_id_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string claim_id = 2;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.claim_id_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string chart = 3;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.chart_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string name = 4;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.name_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string family = 5 [deprecated = true];
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.family_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // uint64 batch_id = 6 [deprecated = true];
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.batch_id_), _Internal::kHasBitsOffset + 15, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
      // uint64 sequence_id = 7 [deprecated = true];
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.sequence_id_), _Internal::kHasBitsOffset + 16, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
      // uint64 when = 8;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.when_), _Internal::kHasBitsOffset + 17, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
      // string config_hash = 9;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.config_hash_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // int32 utc_offset = 10;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.utc_offset_), _Internal::kHasBitsOffset + 18, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
      // string timezone = 11;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.timezone_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string exec_path = 12;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.exec_path_), _Internal::kHasBitsOffset + 7, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string conf_source = 13;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.conf_source_), _Internal::kHasBitsOffset + 8, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string command = 14;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.command_), _Internal::kHasBitsOffset + 9, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // uint32 duration = 15;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.duration_), _Internal::kHasBitsOffset + 19, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
      // uint32 non_clear_duration = 16;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.non_clear_duration_), _Internal::kHasBitsOffset + 20, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
      // .alarms.v1.AlarmStatus status = 17;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.status_), _Internal::kHasBitsOffset + 21, 0, (0 | ::_fl::kFcOptional | ::_fl::kOpenEnum)},
      // .alarms.v1.AlarmStatus old_status = 18;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.old_status_), _Internal::kHasBitsOffset + 25, 0, (0 | ::_fl::kFcOptional | ::_fl::kOpenEnum)},
      // uint64 delay = 19;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.delay_), _Internal::kHasBitsOffset + 22, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
      // uint64 delay_up_to_timestamp = 20;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.delay_up_to_timestamp_), _Internal::kHasBitsOffset + 23, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
      // uint64 last_repeat = 21;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.last_repeat_), _Internal::kHasBitsOffset + 24, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
      // bool silenced = 22;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.silenced_), _Internal::kHasBitsOffset + 26, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // string value_string = 23;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.value_string_), _Internal::kHasBitsOffset + 10, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string old_value_string = 24;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.old_value_string_), _Internal::kHasBitsOffset + 11, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // double value = 25;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.value_), _Internal::kHasBitsOffset + 28, 0, (0 | ::_fl::kFcOptional | ::_fl::kDouble)},
      // double old_value = 26;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.old_value_), _Internal::kHasBitsOffset + 29, 0, (0 | ::_fl::kFcOptional | ::_fl::kDouble)},
      // bool updated = 27;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.updated_), _Internal::kHasBitsOffset + 27, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // string rendered_info = 28;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.rendered_info_), _Internal::kHasBitsOffset + 12, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string chart_context = 29;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.chart_context_), _Internal::kHasBitsOffset + 13, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // uint64 event_id = 30;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.event_id_), _Internal::kHasBitsOffset + 30, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
      // string transition_id = 31;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.transition_id_), _Internal::kHasBitsOffset + 14, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string chart_name = 32;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.chart_name_), _Internal::kHasBitsOffset + 31, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string summary = 33;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.summary_), _Internal::kHasBitsOffset + 32, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // uint64 alert_version = 34;
      {PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.alert_version_), _Internal::kHasBitsOffset + 33, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
    }},
    // no aux_entries
    {{
      "\27\7\10\5\4\6\0\0\0\13\0\10\11\13\7\0\0\0\0\0\0\0\0\14\20\0\0\0\15\15\0\15\12\7\0\0\0\0\0\0"
      "alarms.v1.AlarmLogEntry"
      "node_id"
      "claim_id"
      "chart"
      "name"
      "family"
      "config_hash"
      "timezone"
      "exec_path"
      "conf_source"
      "command"
      "value_string"
      "old_value_string"
      "rendered_info"
      "chart_context"
      "transition_id"
      "chart_name"
      "summary"
    }},
  };
}


inline constexpr AlarmLogEntry::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        node_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        claim_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        chart_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        name_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        family_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        config_hash_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        timezone_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        exec_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        conf_source_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        command_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        value_string_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        old_value_string_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        rendered_info_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        chart_context_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        transition_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        batch_id_{::uint64_t{0u}},
        sequence_id_{::uint64_t{0u}},
        when_{::uint64_t{0u}},
        utc_offset_{0},
        duration_{0u},
        non_clear_duration_{0u},
        status_{static_cast< ::alarms::v1::AlarmStatus >(0)},
        delay_{::uint64_t{0u}},
        delay_up_to_timestamp_{::uint64_t{0u}},
        last_repeat_{::uint64_t{0u}},
        old_status_{static_cast< ::alarms::v1::AlarmStatus >(0)},
        silenced_{false},
        updated_{false},
        value_{0},
        old_value_{0},
        event_id_{::uint64_t{0u}},
        chart_name_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        summary_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        alert_version_{::uint64_t{0u}} {}

template <typename>
constexpr AlarmLogEntry::AlarmLogEntry(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL AlarmLogEntry::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) AlarmLogEntry(arena);
}
constexpr auto AlarmLogEntry::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(AlarmLogEntry), alignof(AlarmLogEntry));
}
constexpr auto AlarmLogEntry::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &AlarmLogEntry::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<AlarmLogEntry>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &AlarmLogEntry::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<AlarmLogEntry>(), &AlarmLogEntry::ByteSizeLong,
              &AlarmLogEntry::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[6],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_proto_2falarm_2fv1_2fstream_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct AlarmLogEntryGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr AlarmLogEntryGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 AlarmLogEntry_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(AlarmLogEntry::InternalGenerateClassData_(
            _default, &AlarmLogEntry_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<AlarmLogEntry>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~AlarmLogEntryGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) AlarmLogEntry _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<AlarmLogEntry>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(AlarmLogEntryGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST AlarmLogEntryGlobalsTypeInternal AlarmLogEntry_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* AlarmLogEntry_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return AlarmLogEntry_globals_.GetClassData();
#else
  return AlarmLogEntry_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class AlarmCheckpoint::_Internal {
 public:
  using HasBits = decltype(::std::declval<AlarmCheckpoint>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(AlarmCheckpoint, _impl_._has_bits_);
};

constexpr AlarmCheckpoint::ParseTableT_ AlarmCheckpoint::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(AlarmCheckpoint, _impl_._has_bits_),
      0, // no _extensions_
      3, 24,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967288,  // skipmap
      offsetof(ParseTableT_, field_entries),
      3,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::alarms::v1::AlarmCheckpoint>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // string node_id = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(AlarmCheckpoint, _impl_.node_id_)}},
      // string claim_id = 2;
      {::_pbi::TcParser::FastUS1,
       {18, 1, 0,
        PROTOBUF_FIELD_OFFSET(AlarmCheckpoint, _impl_.claim_id_)}},
      // bytes checksum = 3;
      {::_pbi::TcParser::FastBS1,
       {26, 2, 0,
        PROTOBUF_FIELD_OFFSET(AlarmCheckpoint, _impl_.checksum_)}},
    }}, {{
      65535, 65535
    }}, {{
      // string node_id = 1;
      {PROTOBUF_FIELD_OFFSET(AlarmCheckpoint, _impl_.node_id_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string claim_id = 2;
      {PROTOBUF_FIELD_OFFSET(AlarmCheckpoint, _impl_.claim_id_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // bytes checksum = 3;
      {PROTOBUF_FIELD_OFFSET(AlarmCheckpoint, _impl_.checksum_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kBytes | ::_fl::kRepAString)},
    }},
    // no aux_entries
    {{
      "\31\7\10\0\0\0\0\0"
      "alarms.v1.AlarmCheckpoint"
      "node_id"
      "claim_id"
    }},
  };
}


inline constexpr AlarmCheckpoint::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        node_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        claim_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        checksum_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()) {}

template <typename>
constexpr AlarmCheckpoint::AlarmCheckpoint(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL AlarmCheckpoint::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) AlarmCheckpoint(arena);
}
constexpr auto AlarmCheckpoint::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(AlarmCheckpoint), alignof(AlarmCheckpoint));
}
constexpr auto AlarmCheckpoint::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &AlarmCheckpoint::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<AlarmCheckpoint>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &AlarmCheckpoint::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<AlarmCheckpoint>(), &AlarmCheckpoint::ByteSizeLong,
              &AlarmCheckpoint::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(AlarmCheckpoint, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[5],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_proto_2falarm_2fv1_2fstream_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct AlarmCheckpointGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr AlarmCheckpointGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 AlarmCheckpoint_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(AlarmCheckpoint::InternalGenerateClassData_(
            _default, &AlarmCheckpoint_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<AlarmCheckpoint>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~AlarmCheckpointGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) AlarmCheckpoint _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<AlarmCheckpoint>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(AlarmCheckpointGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST AlarmCheckpointGlobalsTypeInternal AlarmCheckpoint_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* AlarmCheckpoint_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return AlarmCheckpoint_globals_.GetClassData();
#else
  return AlarmCheckpoint_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class LogEntries::_Internal {
 public:
  using HasBits = decltype(::std::declval<LogEntries>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(LogEntries, _impl_._has_bits_);
};

constexpr LogEntries::ParseTableT_ LogEntries::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(LogEntries, _impl_._has_bits_),
      0, // no _extensions_
      4, 24,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967280,  // skipmap
      offsetof(ParseTableT_, field_entries),
      4,  // num_field_entries
      2,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::alarms::v1::LogEntries>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // .google.protobuf.Timestamp last_when = 4;
      {::_pbi::TcParser::FastMtS1,
       {34, 1, 1,
        PROTOBUF_FIELD_OFFSET(LogEntries, _impl_.last_when_)}},
      // int64 first_sequence_id = 1;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(LogEntries, _impl_.first_sequence_id_), 2>(),
       {8, 2, 0,
        PROTOBUF_FIELD_OFFSET(LogEntries, _impl_.first_sequence_id_)}},
      // .google.protobuf.Timestamp first_when = 2;
      {::_pbi::TcParser::FastMtS1,
       {18, 0, 0,
        PROTOBUF_FIELD_OFFSET(LogEntries, _impl_.first_when_)}},
      // int64 last_sequence_id = 3;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(LogEntries, _impl_.last_sequence_id_), 3>(),
       {24, 3, 0,
        PROTOBUF_FIELD_OFFSET(LogEntries, _impl_.last_sequence_id_)}},
    }}, {{
      65535, 65535
    }}, {{
      // int64 first_sequence_id = 1;
      {PROTOBUF_FIELD_OFFSET(LogEntries, _impl_.first_sequence_id_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
      // .google.protobuf.Timestamp first_when = 2;
      {PROTOBUF_FIELD_OFFSET(LogEntries, _impl_.first_when_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // int64 last_sequence_id = 3;
      {PROTOBUF_FIELD_OFFSET(LogEntries, _impl_.last_sequence_id_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
      // .google.protobuf.Timestamp last_when = 4;
      {PROTOBUF_FIELD_OFFSET(LogEntries, _impl_.last_when_), _Internal::kHasBitsOffset + 1, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::google::protobuf::Timestamp>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::google::protobuf::Timestamp_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::google::protobuf::Timestamp>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::google::protobuf::Timestamp_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr LogEntries::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        first_when_{nullptr},
        last_when_{nullptr},
        first_sequence_id_{::int64_t{0}},
        last_sequence_id_{::int64_t{0}} {}

template <typename>
constexpr LogEntries::LogEntries(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL LogEntries::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) LogEntries(arena);
}
constexpr auto LogEntries::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(LogEntries), alignof(LogEntries));
}
constexpr auto LogEntries::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &LogEntries::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<LogEntries>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &LogEntries::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<LogEntries>(), &LogEntries::ByteSizeLong,
              &LogEntries::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(LogEntries, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[2],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_proto_2falarm_2fv1_2fstream_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct LogEntriesGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr LogEntriesGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 LogEntries_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(LogEntries::InternalGenerateClassData_(
            _default, &LogEntries_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<LogEntries>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~LogEntriesGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) LogEntries _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<LogEntries>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(LogEntriesGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST LogEntriesGlobalsTypeInternal LogEntries_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* LogEntries_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return LogEntries_globals_.GetClassData();
#else
  return LogEntries_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class AlarmSnapshot::_Internal {
 public:
  using HasBits = decltype(::std::declval<AlarmSnapshot>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(AlarmSnapshot, _impl_._has_bits_);
};

constexpr AlarmSnapshot::ParseTableT_ AlarmSnapshot::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(AlarmSnapshot, _impl_._has_bits_),
      0, // no _extensions_
      8, 56,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967040,  // skipmap
      offsetof(ParseTableT_, field_entries),
      8,  // num_field_entries
      1,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::alarms::v1::AlarmSnapshot>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // string snapshot_uuid = 8;
      {::_pbi::TcParser::FastUS1,
       {66, 3, 0,
        PROTOBUF_FIELD_OFFSET(AlarmSnapshot, _impl_.snapshot_uuid_)}},
      // string node_id = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 1, 0,
        PROTOBUF_FIELD_OFFSET(AlarmSnapshot, _impl_.node_id_)}},
      // string claim_id = 2;
      {::_pbi::TcParser::FastUS1,
       {18, 2, 0,
        PROTOBUF_FIELD_OFFSET(AlarmSnapshot, _impl_.claim_id_)}},
      // uint64 snapshot_id = 3 [deprecated = true];
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(AlarmSnapshot, _impl_.snapshot_id_), 4>(),
       {24, 4, 0,
        PROTOBUF_FIELD_OFFSET(AlarmSnapshot, _impl_.snapshot_id_)}},
      // uint32 chunks = 4;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(AlarmSnapshot, _impl_.chunks_), 5>(),
       {32, 5, 0,
        PROTOBUF_FIELD_OFFSET(AlarmSnapshot, _impl_.chunks_)}},
      // uint32 chunk_size = 5;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(AlarmSnapshot, _impl_.chunk_size_), 6>(),
       {40, 6, 0,
        PROTOBUF_FIELD_OFFSET(AlarmSnapshot, _impl_.chunk_size_)}},
      // uint32 chunk = 6;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(AlarmSnapshot, _impl_.chunk_), 7>(),
       {48, 7, 0,
        PROTOBUF_FIELD_OFFSET(AlarmSnapshot, _impl_.chunk_)}},
      // repeated .alarms.v1.AlarmLogEntry alarms = 7;
      {::_pbi::TcParser::FastMtR1,
       {58, 0, 0,
        PROTOBUF_FIELD_OFFSET(AlarmSnapshot, _impl_.alarms_)}},
    }}, {{
      65535, 65535
    }}, {{
      // string node_id = 1;
      {PROTOBUF_FIELD_OFFSET(AlarmSnapshot, _impl_.node_id_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string claim_id = 2;
      {PROTOBUF_FIELD_OFFSET(AlarmSnapshot, _impl_.claim_id_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // uint64 snapshot_id = 3 [deprecated = true];
      {PROTOBUF_FIELD_OFFSET(AlarmSnapshot, _impl_.snapshot_id_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt64)},
      // uint32 chunks = 4;
      {PROTOBUF_FIELD_OFFSET(AlarmSnapshot, _impl_.chunks_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
      // uint32 chunk_size = 5;
      {PROTOBUF_FIELD_OFFSET(AlarmSnapshot, _impl_.chunk_size_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
      // uint32 chunk = 6;
      {PROTOBUF_FIELD_OFFSET(AlarmSnapshot, _impl_.chunk_), _Internal::kHasBitsOffset + 7, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
      // repeated .alarms.v1.AlarmLogEntry alarms = 7;
      {PROTOBUF_FIELD_OFFSET(AlarmSnapshot, _impl_.alarms_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
      // string snapshot_uuid = 8;
      {PROTOBUF_FIELD_OFFSET(AlarmSnapshot, _impl_.snapshot_uuid_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::alarms::v1::AlarmLogEntry>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::alarms::v1::AlarmLogEntry_globals_},
        #endif
    }},
    {{
      "\27\7\10\0\0\0\0\0\15\0\0\0\0\0\0\0"
      "alarms.v1.AlarmSnapshot"
      "node_id"
      "claim_id"
      "snapshot_uuid"
    }},
  };
}


inline constexpr AlarmSnapshot::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        alarms_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::alarms::v1::AlarmSnapshot,
            PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmSnapshot, _impl_.alarms_)>()
         }
        ,
        node_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        claim_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        snapshot_uuid_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        snapshot_id_{::uint64_t{0u}},
        chunks_{0u},
        chunk_size_{0u},
        chunk_{0u} {}

template <typename>
constexpr AlarmSnapshot::AlarmSnapshot(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL AlarmSnapshot::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) AlarmSnapshot(arena);
}
constexpr auto AlarmSnapshot::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(AlarmSnapshot), alignof(AlarmSnapshot));
}
constexpr auto AlarmSnapshot::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &AlarmSnapshot::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<AlarmSnapshot>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &AlarmSnapshot::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<AlarmSnapshot>(), &AlarmSnapshot::ByteSizeLong,
              &AlarmSnapshot::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(AlarmSnapshot, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[8],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_proto_2falarm_2fv1_2fstream_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct AlarmSnapshotGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr AlarmSnapshotGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 AlarmSnapshot_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(AlarmSnapshot::InternalGenerateClassData_(
            _default, &AlarmSnapshot_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<AlarmSnapshot>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~AlarmSnapshotGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) AlarmSnapshot _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<AlarmSnapshot>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(AlarmSnapshotGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST AlarmSnapshotGlobalsTypeInternal AlarmSnapshot_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* AlarmSnapshot_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return AlarmSnapshot_globals_.GetClassData();
#else
  return AlarmSnapshot_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class AlarmLogHealth::_Internal {
 public:
  using HasBits = decltype(::std::declval<AlarmLogHealth>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(AlarmLogHealth, _impl_._has_bits_);
};

constexpr AlarmLogHealth::ParseTableT_ AlarmLogHealth::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(AlarmLogHealth, _impl_._has_bits_),
      0, // no _extensions_
      5, 56,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967264,  // skipmap
      offsetof(ParseTableT_, field_entries),
      5,  // num_field_entries
      1,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::alarms::v1::AlarmLogHealth>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // string claim_id = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogHealth, _impl_.claim_id_)}},
      // string node_id = 2;
      {::_pbi::TcParser::FastUS1,
       {18, 1, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogHealth, _impl_.node_id_)}},
      // bool enabled = 3;
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(AlarmLogHealth, _impl_.enabled_), 3>(),
       {24, 3, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogHealth, _impl_.enabled_)}},
      // .alarms.v1.AlarmLogStatus status = 4;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(AlarmLogHealth, _impl_.status_), 4>(),
       {32, 4, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogHealth, _impl_.status_)}},
      // .alarms.v1.LogEntries log_entries = 5;
      {::_pbi::TcParser::FastMtS1,
       {42, 2, 0,
        PROTOBUF_FIELD_OFFSET(AlarmLogHealth, _impl_.log_entries_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // string claim_id = 1;
      {PROTOBUF_FIELD_OFFSET(AlarmLogHealth, _impl_.claim_id_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string node_id = 2;
      {PROTOBUF_FIELD_OFFSET(AlarmLogHealth, _impl_.node_id_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // bool enabled = 3;
      {PROTOBUF_FIELD_OFFSET(AlarmLogHealth, _impl_.enabled_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // .alarms.v1.AlarmLogStatus status = 4;
      {PROTOBUF_FIELD_OFFSET(AlarmLogHealth, _impl_.status_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kOpenEnum)},
      // .alarms.v1.LogEntries log_entries = 5;
      {PROTOBUF_FIELD_OFFSET(AlarmLogHealth, _impl_.log_entries_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::alarms::v1::LogEntries>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::alarms::v1::LogEntries_globals_},
        #endif
    }},
    {{
      "\30\10\7\0\0\0\0\0"
      "alarms.v1.AlarmLogHealth"
      "claim_id"
      "node_id"
    }},
  };
}


inline constexpr AlarmLogHealth::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        claim_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        node_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        log_entries_{nullptr},
        enabled_{false},
        status_{static_cast< ::alarms::v1::AlarmLogStatus >(0)} {}

template <typename>
constexpr AlarmLogHealth::AlarmLogHealth(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL AlarmLogHealth::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) AlarmLogHealth(arena);
}
constexpr auto AlarmLogHealth::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(AlarmLogHealth), alignof(AlarmLogHealth));
}
constexpr auto AlarmLogHealth::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &AlarmLogHealth::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<AlarmLogHealth>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &AlarmLogHealth::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<AlarmLogHealth>(), &AlarmLogHealth::ByteSizeLong,
              &AlarmLogHealth::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(AlarmLogHealth, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[1],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_proto_2falarm_2fv1_2fstream_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct AlarmLogHealthGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr AlarmLogHealthGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 AlarmLogHealth_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(AlarmLogHealth::InternalGenerateClassData_(
            _default, &AlarmLogHealth_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<AlarmLogHealth>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~AlarmLogHealthGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) AlarmLogHealth _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<AlarmLogHealth>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(AlarmLogHealthGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST AlarmLogHealthGlobalsTypeInternal AlarmLogHealth_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* AlarmLogHealth_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return AlarmLogHealth_globals_.GetClassData();
#else
  return AlarmLogHealth_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
}  // namespace v1
}  // namespace alarms
static const ::_pb::EnumDescriptor* PROTOBUF_NONNULL
    file_level_enum_descriptors_proto_2falarm_2fv1_2fstream_2eproto[2];
static constexpr const ::_pb::ServiceDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_service_descriptors_proto_2falarm_2fv1_2fstream_2eproto = nullptr;
const ::uint32_t
    TableStruct_proto_2falarm_2fv1_2fstream_2eproto::offsets[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
        protodesc_cold) = {
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::alarms::v1::SendAlarmLogHealth, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::alarms::v1::SendAlarmLogHealth, _impl_.node_id_),
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogHealth, _impl_._has_bits_),
        8, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogHealth, _impl_.claim_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogHealth, _impl_.node_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogHealth, _impl_.enabled_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogHealth, _impl_.status_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogHealth, _impl_.log_entries_),
        0,
        1,
        3,
        4,
        2,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::alarms::v1::LogEntries, _impl_._has_bits_),
        7, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::alarms::v1::LogEntries, _impl_.first_sequence_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::LogEntries, _impl_.first_when_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::LogEntries, _impl_.last_sequence_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::LogEntries, _impl_.last_when_),
        2,
        0,
        3,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::alarms::v1::StartAlarmStreaming, _impl_._has_bits_),
        8, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::alarms::v1::StartAlarmStreaming, _impl_.node_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::StartAlarmStreaming, _impl_.batch_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::StartAlarmStreaming, _impl_.start_sequnce_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::StartAlarmStreaming, _impl_.resets_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::StartAlarmStreaming, _impl_.version_),
        0,
        1,
        2,
        4,
        3,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::alarms::v1::SendAlarmCheckpoint, _impl_._has_bits_),
        6, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::alarms::v1::SendAlarmCheckpoint, _impl_.node_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::SendAlarmCheckpoint, _impl_.claim_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::SendAlarmCheckpoint, _impl_.version_),
        0,
        1,
        2,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmCheckpoint, _impl_._has_bits_),
        6, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmCheckpoint, _impl_.node_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmCheckpoint, _impl_.claim_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmCheckpoint, _impl_.checksum_),
        0,
        1,
        2,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_._has_bits_),
        37, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.node_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.claim_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.chart_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.name_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.family_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.batch_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.sequence_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.when_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.config_hash_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.utc_offset_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.timezone_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.exec_path_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.conf_source_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.command_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.duration_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.non_clear_duration_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.status_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.old_status_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.delay_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.delay_up_to_timestamp_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.last_repeat_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.silenced_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.value_string_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.old_value_string_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.value_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.old_value_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.updated_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.rendered_info_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.chart_context_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.event_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.transition_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.chart_name_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.summary_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmLogEntry, _impl_.alert_version_),
        0,
        1,
        2,
        3,
        4,
        15,
        16,
        17,
        5,
        18,
        6,
        7,
        8,
        9,
        19,
        20,
        21,
        25,
        22,
        23,
        24,
        26,
        10,
        11,
        28,
        29,
        27,
        12,
        13,
        30,
        14,
        31,
        32,
        33,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::alarms::v1::SendAlarmSnapshot, _impl_._has_bits_),
        8, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::alarms::v1::SendAlarmSnapshot, _impl_.node_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::SendAlarmSnapshot, _impl_.claim_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::SendAlarmSnapshot, _impl_.snapshot_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::SendAlarmSnapshot, _impl_.sequence_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::SendAlarmSnapshot, _impl_.snapshot_uuid_),
        0,
        1,
        3,
        4,
        2,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmSnapshot, _impl_._has_bits_),
        11, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmSnapshot, _impl_.node_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmSnapshot, _impl_.claim_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmSnapshot, _impl_.snapshot_id_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmSnapshot, _impl_.chunks_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmSnapshot, _impl_.chunk_size_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmSnapshot, _impl_.chunk_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmSnapshot, _impl_.alarms_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmSnapshot, _impl_.snapshot_uuid_),
        1,
        2,
        4,
        5,
        6,
        7,
        0,
        3,
};

static const ::_pbi::MigrationSchema
    schemas[] ABSL_ATTRIBUTE_SECTION_VARIABLE(protodesc_cold) = {
        {0, sizeof(::alarms::v1::SendAlarmLogHealth)},
        {5, sizeof(::alarms::v1::AlarmLogHealth)},
        {18, sizeof(::alarms::v1::LogEntries)},
        {29, sizeof(::alarms::v1::StartAlarmStreaming)},
        {42, sizeof(::alarms::v1::SendAlarmCheckpoint)},
        {51, sizeof(::alarms::v1::AlarmCheckpoint)},
        {60, sizeof(::alarms::v1::AlarmLogEntry)},
        {131, sizeof(::alarms::v1::SendAlarmSnapshot)},
        {144, sizeof(::alarms::v1::AlarmSnapshot)},
};
static const ::_pbi::MessageGlobalsBase* PROTOBUF_NONNULL const
    file_message_globals[] = {
        &::alarms::v1::SendAlarmLogHealth_globals_,
        &::alarms::v1::AlarmLogHealth_globals_,
        &::alarms::v1::LogEntries_globals_,
        &::alarms::v1::StartAlarmStreaming_globals_,
        &::alarms::v1::SendAlarmCheckpoint_globals_,
        &::alarms::v1::AlarmCheckpoint_globals_,
        &::alarms::v1::AlarmLogEntry_globals_,
        &::alarms::v1::SendAlarmSnapshot_globals_,
        &::alarms::v1::AlarmSnapshot_globals_,
};
const char descriptor_table_protodef_proto_2falarm_2fv1_2fstream_2eproto[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
    protodesc_cold) = {
    "\n\033proto/alarm/v1/stream.proto\022\talarms.v1"
    "\032\037google/protobuf/timestamp.proto\"%\n\022Sen"
    "dAlarmLogHealth\022\017\n\007node_id\030\001 \001(\t\"\233\001\n\016Ala"
    "rmLogHealth\022\020\n\010claim_id\030\001 \001(\t\022\017\n\007node_id"
    "\030\002 \001(\t\022\017\n\007enabled\030\003 \001(\010\022)\n\006status\030\004 \001(\0162"
    "\031.alarms.v1.AlarmLogStatus\022*\n\013log_entrie"
    "s\030\005 \001(\0132\025.alarms.v1.LogEntries\"\240\001\n\nLogEn"
    "tries\022\031\n\021first_sequence_id\030\001 \001(\003\022.\n\nfirs"
    "t_when\030\002 \001(\0132\032.google.protobuf.Timestamp"
    "\022\030\n\020last_sequence_id\030\003 \001(\003\022-\n\tlast_when\030"
    "\004 \001(\0132\032.google.protobuf.Timestamp\"{\n\023Sta"
    "rtAlarmStreaming\022\017\n\007node_id\030\001 \001(\t\022\024\n\010bat"
    "ch_id\030\002 \001(\004B\002\030\001\022\034\n\020start_sequnce_id\030\003 \001("
    "\004B\002\030\001\022\016\n\006resets\030\004 \001(\010\022\017\n\007version\030\005 \001(\004\"I"
    "\n\023SendAlarmCheckpoint\022\017\n\007node_id\030\001 \001(\t\022\020"
    "\n\010claim_id\030\002 \001(\t\022\017\n\007version\030\003 \001(\004\"F\n\017Ala"
    "rmCheckpoint\022\017\n\007node_id\030\001 \001(\t\022\020\n\010claim_i"
    "d\030\002 \001(\t\022\020\n\010checksum\030\003 \001(\014\"\341\005\n\rAlarmLogEn"
    "try\022\017\n\007node_id\030\001 \001(\t\022\020\n\010claim_id\030\002 \001(\t\022\r"
    "\n\005chart\030\003 \001(\t\022\014\n\004name\030\004 \001(\t\022\022\n\006family\030\005 "
    "\001(\tB\002\030\001\022\024\n\010batch_id\030\006 \001(\004B\002\030\001\022\027\n\013sequenc"
    "e_id\030\007 \001(\004B\002\030\001\022\014\n\004when\030\010 \001(\004\022\023\n\013config_h"
    "ash\030\t \001(\t\022\022\n\nutc_offset\030\n \001(\005\022\020\n\010timezon"
    "e\030\013 \001(\t\022\021\n\texec_path\030\014 \001(\t\022\023\n\013conf_sourc"
    "e\030\r \001(\t\022\017\n\007command\030\016 \001(\t\022\020\n\010duration\030\017 \001"
    "(\r\022\032\n\022non_clear_duration\030\020 \001(\r\022&\n\006status"
    "\030\021 \001(\0162\026.alarms.v1.AlarmStatus\022*\n\nold_st"
    "atus\030\022 \001(\0162\026.alarms.v1.AlarmStatus\022\r\n\005de"
    "lay\030\023 \001(\004\022\035\n\025delay_up_to_timestamp\030\024 \001(\004"
    "\022\023\n\013last_repeat\030\025 \001(\004\022\020\n\010silenced\030\026 \001(\010\022"
    "\024\n\014value_string\030\027 \001(\t\022\030\n\020old_value_strin"
    "g\030\030 \001(\t\022\r\n\005value\030\031 \001(\001\022\021\n\told_value\030\032 \001("
    "\001\022\017\n\007updated\030\033 \001(\010\022\025\n\rrendered_info\030\034 \001("
    "\t\022\025\n\rchart_context\030\035 \001(\t\022\020\n\010event_id\030\036 \001"
    "(\004\022\025\n\rtransition_id\030\037 \001(\t\022\022\n\nchart_name\030"
    "  \001(\t\022\017\n\007summary\030! \001(\t\022\025\n\ralert_version\030"
    "\" \001(\004\"\177\n\021SendAlarmSnapshot\022\017\n\007node_id\030\001 "
    "\001(\t\022\020\n\010claim_id\030\002 \001(\t\022\027\n\013snapshot_id\030\003 \001"
    "(\004B\002\030\001\022\027\n\013sequence_id\030\004 \001(\004B\002\030\001\022\025\n\rsnaps"
    "hot_uuid\030\005 \001(\t\"\277\001\n\rAlarmSnapshot\022\017\n\007node"
    "_id\030\001 \001(\t\022\020\n\010claim_id\030\002 \001(\t\022\027\n\013snapshot_"
    "id\030\003 \001(\004B\002\030\001\022\016\n\006chunks\030\004 \001(\r\022\022\n\nchunk_si"
    "ze\030\005 \001(\r\022\r\n\005chunk\030\006 \001(\r\022(\n\006alarms\030\007 \003(\0132"
    "\030.alarms.v1.AlarmLogEntry\022\025\n\rsnapshot_uu"
    "id\030\010 \001(\t*k\n\016AlarmLogStatus\022 \n\034ALARM_LOG_"
    "STATUS_UNSPECIFIED\020\000\022\034\n\030ALARM_LOG_STATUS"
    "_RUNNING\020\001\022\031\n\025ALARM_LOG_STATUS_IDLE\020\002*\304\001"
    "\n\013AlarmStatus\022\025\n\021ALARM_STATUS_NULL\020\000\022\030\n\024"
    "ALARM_STATUS_UNKNOWN\020\001\022\030\n\024ALARM_STATUS_R"
    "EMOVED\020\002\022\035\n\031ALARM_STATUS_NOT_A_NUMBER\020\003\022"
    "\026\n\022ALARM_STATUS_CLEAR\020\004\022\030\n\024ALARM_STATUS_"
    "WARNING\020\005\022\031\n\025ALARM_STATUS_CRITICAL\020\006B\022Z\020"
    "alarms/v1;alarmsb\006proto3"
};
static const ::_pbi::DescriptorTable* PROTOBUF_NONNULL const
    descriptor_table_proto_2falarm_2fv1_2fstream_2eproto_deps[1] = {
        &::descriptor_table_google_2fprotobuf_2ftimestamp_2eproto,
};
static ::absl::once_flag descriptor_table_proto_2falarm_2fv1_2fstream_2eproto_once;
PROTOBUF_CONSTINIT const ::_pbi::DescriptorTable descriptor_table_proto_2falarm_2fv1_2fstream_2eproto = {
    false,
    false,
    2104,
    descriptor_table_protodef_proto_2falarm_2fv1_2fstream_2eproto,
    "proto/alarm/v1/stream.proto",
    &descriptor_table_proto_2falarm_2fv1_2fstream_2eproto_once,
    descriptor_table_proto_2falarm_2fv1_2fstream_2eproto_deps,
    1,
    9,
    schemas,
    file_message_globals,
    TableStruct_proto_2falarm_2fv1_2fstream_2eproto::offsets,
    file_level_enum_descriptors_proto_2falarm_2fv1_2fstream_2eproto,
    file_level_service_descriptors_proto_2falarm_2fv1_2fstream_2eproto,
};
namespace alarms {
namespace v1 {
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
AlarmLogStatus_descriptor() {
  ::google::protobuf::internal::AssignDescriptors(&descriptor_table_proto_2falarm_2fv1_2fstream_2eproto);
  return file_level_enum_descriptors_proto_2falarm_2fv1_2fstream_2eproto[0];
}
PROTOBUF_CONSTINIT const uint32_t AlarmLogStatus_internal_data_[] = {
    196608u, 0u, };
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
AlarmStatus_descriptor() {
  ::google::protobuf::internal::AssignDescriptors(&descriptor_table_proto_2falarm_2fv1_2fstream_2eproto);
  return file_level_enum_descriptors_proto_2falarm_2fv1_2fstream_2eproto[1];
}
PROTOBUF_CONSTINIT const uint32_t AlarmStatus_internal_data_[] = {
    458752u, 0u, };
// ===================================================================

SendAlarmLogHealth::SendAlarmLogHealth(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, SendAlarmLogHealth_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:alarms.v1.SendAlarmLogHealth)
}
PROTOBUF_NDEBUG_INLINE SendAlarmLogHealth::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::alarms::v1::SendAlarmLogHealth& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        node_id_(arena, from.node_id_) {}

SendAlarmLogHealth::SendAlarmLogHealth(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const SendAlarmLogHealth& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, SendAlarmLogHealth_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SendAlarmLogHealth* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:alarms.v1.SendAlarmLogHealth)
}
PROTOBUF_NDEBUG_INLINE SendAlarmLogHealth::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        node_id_(arena) {}

inline void SendAlarmLogHealth::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
SendAlarmLogHealth::~SendAlarmLogHealth() {
  // @@protoc_insertion_point(destructor:alarms.v1.SendAlarmLogHealth)
  SharedDtor(*this);
}
inline void SendAlarmLogHealth::SharedDtor(MessageLite& self) {
  SendAlarmLogHealth& this_ = static_cast<SendAlarmLogHealth&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.node_id_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull SendAlarmLogHealth_class_data_ =
        SendAlarmLogHealth::InternalGenerateClassData_(SendAlarmLogHealth_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
SendAlarmLogHealth::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&SendAlarmLogHealth_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(SendAlarmLogHealth_class_data_.tc_table);
  return SendAlarmLogHealth_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
SendAlarmLogHealth::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&SendAlarmLogHealth_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&SendAlarmLogHealth_globals_));
  return SendAlarmLogHealth_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const SendAlarmLogHealth::ParseTableT_
    SendAlarmLogHealth::_table_ =
        SendAlarmLogHealth::InternalGenerateParseTable_(SendAlarmLogHealth_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void SendAlarmLogHealth::Clear() {
// @@protoc_insertion_point(message_clear_start:alarms.v1.SendAlarmLogHealth)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _impl_.node_id_.ClearNonDefaultToEmpty();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL SendAlarmLogHealth::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const SendAlarmLogHealth& this_ = static_cast<const SendAlarmLogHealth&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL SendAlarmLogHealth::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const SendAlarmLogHealth& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:alarms.v1.SendAlarmLogHealth)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string node_id = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_node_id().empty()) {
      const ::std::string& _s = this_._internal_node_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.SendAlarmLogHealth.node_id");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:alarms.v1.SendAlarmLogHealth)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t SendAlarmLogHealth::ByteSizeLong(const MessageLite& base) {
  const SendAlarmLogHealth& this_ = static_cast<const SendAlarmLogHealth&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t SendAlarmLogHealth::ByteSizeLong() const {
  const SendAlarmLogHealth& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:alarms.v1.SendAlarmLogHealth)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

   {
    // string node_id = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_node_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_node_id());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void SendAlarmLogHealth::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<SendAlarmLogHealth*>(&to_msg);
  auto& from = static_cast<const SendAlarmLogHealth&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:alarms.v1.SendAlarmLogHealth)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!from._internal_node_id().empty()) {
      _this->_internal_set_node_id(from._internal_node_id());
    } else {
      if (_this->_impl_.node_id_.IsDefault()) {
        _this->_internal_set_node_id("");
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void SendAlarmLogHealth::CopyFrom(const SendAlarmLogHealth& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:alarms.v1.SendAlarmLogHealth)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void SendAlarmLogHealth::InternalSwap(SendAlarmLogHealth* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.node_id_, &other->_impl_.node_id_, arena);
}

::google::protobuf::Metadata SendAlarmLogHealth::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

AlarmLogHealth::AlarmLogHealth(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, AlarmLogHealth_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:alarms.v1.AlarmLogHealth)
}
PROTOBUF_NDEBUG_INLINE AlarmLogHealth::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::alarms::v1::AlarmLogHealth& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        claim_id_(arena, from.claim_id_),
        node_id_(arena, from.node_id_) {}

AlarmLogHealth::AlarmLogHealth(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const AlarmLogHealth& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, AlarmLogHealth_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  AlarmLogHealth* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.log_entries_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.log_entries_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, enabled_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, enabled_),
           offsetof(Impl_, status_) -
               offsetof(Impl_, enabled_) +
               sizeof(Impl_::status_));

  // @@protoc_insertion_point(copy_constructor:alarms.v1.AlarmLogHealth)
}
PROTOBUF_NDEBUG_INLINE AlarmLogHealth::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        claim_id_(arena),
        node_id_(arena) {}

inline void AlarmLogHealth::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, log_entries_),
           0,
           offsetof(Impl_, status_) -
               offsetof(Impl_, log_entries_) +
               sizeof(Impl_::status_));
}
AlarmLogHealth::~AlarmLogHealth() {
  // @@protoc_insertion_point(destructor:alarms.v1.AlarmLogHealth)
  SharedDtor(*this);
}
inline void AlarmLogHealth::SharedDtor(MessageLite& self) {
  AlarmLogHealth& this_ = static_cast<AlarmLogHealth&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.claim_id_.Destroy();
  this_._impl_.node_id_.Destroy();
  delete this_._impl_.log_entries_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull AlarmLogHealth_class_data_ =
        AlarmLogHealth::InternalGenerateClassData_(AlarmLogHealth_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
AlarmLogHealth::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&AlarmLogHealth_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(AlarmLogHealth_class_data_.tc_table);
  return AlarmLogHealth_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
AlarmLogHealth::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&AlarmLogHealth_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&AlarmLogHealth_globals_));
  return AlarmLogHealth_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const AlarmLogHealth::ParseTableT_
    AlarmLogHealth::_table_ =
        AlarmLogHealth::InternalGenerateParseTable_(AlarmLogHealth_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void AlarmLogHealth::Clear() {
// @@protoc_insertion_point(message_clear_start:alarms.v1.AlarmLogHealth)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.claim_id_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.node_id_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.log_entries_ != nullptr);
      _impl_.log_entries_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000018U)) {
    ::memset(&_impl_.enabled_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.status_) -
        reinterpret_cast<char*>(&_impl_.enabled_)) + sizeof(_impl_.status_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL AlarmLogHealth::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const AlarmLogHealth& this_ = static_cast<const AlarmLogHealth&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL AlarmLogHealth::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const AlarmLogHealth& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:alarms.v1.AlarmLogHealth)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string claim_id = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_claim_id().empty()) {
      const ::std::string& _s = this_._internal_claim_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmLogHealth.claim_id");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // string node_id = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_node_id().empty()) {
      const ::std::string& _s = this_._internal_node_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmLogHealth.node_id");
      target = stream->WriteStringMaybeAliased(2, _s, target);
    }
  }

  // bool enabled = 3;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_enabled() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          3, this_._internal_enabled(), target);
    }
  }

  // .alarms.v1.AlarmLogStatus status = 4;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_status() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteEnumToArray(
          4, this_._internal_status(), target);
    }
  }

  // .alarms.v1.LogEntries log_entries = 5;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        5, *this_._impl_.log_entries_, this_._impl_.log_entries_->GetCachedSize(), target,
        stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:alarms.v1.AlarmLogHealth)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t AlarmLogHealth::ByteSizeLong(const MessageLite& base) {
  const AlarmLogHealth& this_ = static_cast<const AlarmLogHealth&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t AlarmLogHealth::ByteSizeLong() const {
  const AlarmLogHealth& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:alarms.v1.AlarmLogHealth)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    // string claim_id = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_claim_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_claim_id());
      }
    }
    // string node_id = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_node_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_node_id());
      }
    }
    // .alarms.v1.LogEntries log_entries = 5;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.log_entries_);
    }
    // bool enabled = 3;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_enabled() != 0) {
        total_size += 2;
      }
    }
    // .alarms.v1.AlarmLogStatus status = 4;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_status() != 0) {
        total_size += 1 +
                      ::_pbi::WireFormatLite::EnumSize(this_._internal_status());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void AlarmLogHealth::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<AlarmLogHealth*>(&to_msg);
  auto& from = static_cast<const AlarmLogHealth&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:alarms.v1.AlarmLogHealth)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_claim_id().empty()) {
        _this->_internal_set_claim_id(from._internal_claim_id());
      } else {
        if (_this->_impl_.claim_id_.IsDefault()) {
          _this->_internal_set_claim_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_node_id().empty()) {
        _this->_internal_set_node_id(from._internal_node_id());
      } else {
        if (_this->_impl_.node_id_.IsDefault()) {
          _this->_internal_set_node_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.log_entries_ != nullptr);
      if (_this->_impl_.log_entries_ == nullptr) {
        _this->_impl_.log_entries_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.log_entries_);
      } else {
        _this->_impl_.log_entries_->MergeFrom(*from._impl_.log_entries_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_enabled() != 0) {
        _this->_impl_.enabled_ = from._impl_.enabled_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_status() != 0) {
        _this->_impl_.status_ = from._impl_.status_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void AlarmLogHealth::CopyFrom(const AlarmLogHealth& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:alarms.v1.AlarmLogHealth)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void AlarmLogHealth::InternalSwap(AlarmLogHealth* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.claim_id_, &other->_impl_.claim_id_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.node_id_, &other->_impl_.node_id_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(AlarmLogHealth, _impl_.status_)
      + sizeof(AlarmLogHealth::_impl_.status_)
      - PROTOBUF_FIELD_OFFSET(AlarmLogHealth, _impl_.log_entries_)>(
          reinterpret_cast<char*>(&_impl_.log_entries_),
          reinterpret_cast<char*>(&other->_impl_.log_entries_));
}

::google::protobuf::Metadata AlarmLogHealth::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

void LogEntries::clear_first_when() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.first_when_ != nullptr) _impl_.first_when_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
void LogEntries::clear_last_when() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.last_when_ != nullptr) _impl_.last_when_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
LogEntries::LogEntries(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, LogEntries_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:alarms.v1.LogEntries)
}
PROTOBUF_NDEBUG_INLINE LogEntries::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::alarms::v1::LogEntries& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0} {}

LogEntries::LogEntries(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const LogEntries& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, LogEntries_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  LogEntries* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.first_when_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.first_when_)
                : nullptr;
  _impl_.last_when_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.last_when_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, first_sequence_id_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, first_sequence_id_),
           offsetof(Impl_, last_sequence_id_) -
               offsetof(Impl_, first_sequence_id_) +
               sizeof(Impl_::last_sequence_id_));

  // @@protoc_insertion_point(copy_constructor:alarms.v1.LogEntries)
}
PROTOBUF_NDEBUG_INLINE LogEntries::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void LogEntries::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, first_when_),
           0,
           offsetof(Impl_, last_sequence_id_) -
               offsetof(Impl_, first_when_) +
               sizeof(Impl_::last_sequence_id_));
}
LogEntries::~LogEntries() {
  // @@protoc_insertion_point(destructor:alarms.v1.LogEntries)
  SharedDtor(*this);
}
inline void LogEntries::SharedDtor(MessageLite& self) {
  LogEntries& this_ = static_cast<LogEntries&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.first_when_;
  delete this_._impl_.last_when_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull LogEntries_class_data_ =
        LogEntries::InternalGenerateClassData_(LogEntries_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
LogEntries::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&LogEntries_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(LogEntries_class_data_.tc_table);
  return LogEntries_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
LogEntries::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&LogEntries_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&LogEntries_globals_));
  return LogEntries_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const LogEntries::ParseTableT_
    LogEntries::_table_ =
        LogEntries::InternalGenerateParseTable_(LogEntries_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void LogEntries::Clear() {
// @@protoc_insertion_point(message_clear_start:alarms.v1.LogEntries)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(_impl_.first_when_ != nullptr);
      _impl_.first_when_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.last_when_ != nullptr);
      _impl_.last_when_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000000cU)) {
    ::memset(&_impl_.first_sequence_id_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.last_sequence_id_) -
        reinterpret_cast<char*>(&_impl_.first_sequence_id_)) + sizeof(_impl_.last_sequence_id_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL LogEntries::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const LogEntries& this_ = static_cast<const LogEntries&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL LogEntries::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const LogEntries& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:alarms.v1.LogEntries)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // int64 first_sequence_id = 1;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (this_._internal_first_sequence_id() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<1>(
              stream, this_._internal_first_sequence_id(), target);
    }
  }

  // .google.protobuf.Timestamp first_when = 2;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.first_when_, this_._impl_.first_when_->GetCachedSize(), target,
        stream);
  }

  // int64 last_sequence_id = 3;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_last_sequence_id() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<3>(
              stream, this_._internal_last_sequence_id(), target);
    }
  }

  // .google.protobuf.Timestamp last_when = 4;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        4, *this_._impl_.last_when_, this_._impl_.last_when_->GetCachedSize(), target,
        stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:alarms.v1.LogEntries)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t LogEntries::ByteSizeLong(const MessageLite& base) {
  const LogEntries& this_ = static_cast<const LogEntries&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t LogEntries::ByteSizeLong() const {
  const LogEntries& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:alarms.v1.LogEntries)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    // .google.protobuf.Timestamp first_when = 2;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.first_when_);
    }
    // .google.protobuf.Timestamp last_when = 4;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.last_when_);
    }
    // int64 first_sequence_id = 1;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (this_._internal_first_sequence_id() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_first_sequence_id());
      }
    }
    // int64 last_sequence_id = 3;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_last_sequence_id() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_last_sequence_id());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void LogEntries::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<LogEntries*>(&to_msg);
  auto& from = static_cast<const LogEntries&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:alarms.v1.LogEntries)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(from._impl_.first_when_ != nullptr);
      if (_this->_impl_.first_when_ == nullptr) {
        _this->_impl_.first_when_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.first_when_);
      } else {
        _this->_impl_.first_when_->MergeFrom(*from._impl_.first_when_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.last_when_ != nullptr);
      if (_this->_impl_.last_when_ == nullptr) {
        _this->_impl_.last_when_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.last_when_);
      } else {
        _this->_impl_.last_when_->MergeFrom(*from._impl_.last_when_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (from._internal_first_sequence_id() != 0) {
        _this->_impl_.first_sequence_id_ = from._impl_.first_sequence_id_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_last_sequence_id() != 0) {
        _this->_impl_.last_sequence_id_ = from._impl_.last_sequence_id_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void LogEntries::CopyFrom(const LogEntries& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:alarms.v1.LogEntries)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void LogEntries::InternalSwap(LogEntries* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(LogEntries, _impl_.last_sequence_id_)
      + sizeof(LogEntries::_impl_.last_sequence_id_)
      - PROTOBUF_FIELD_OFFSET(LogEntries, _impl_.first_when_)>(
          reinterpret_cast<char*>(&_impl_.first_when_),
          reinterpret_cast<char*>(&other->_impl_.first_when_));
}

::google::protobuf::Metadata LogEntries::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

StartAlarmStreaming::StartAlarmStreaming(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, StartAlarmStreaming_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:alarms.v1.StartAlarmStreaming)
}
PROTOBUF_NDEBUG_INLINE StartAlarmStreaming::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::alarms::v1::StartAlarmStreaming& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        node_id_(arena, from.node_id_) {}

StartAlarmStreaming::StartAlarmStreaming(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const StartAlarmStreaming& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, StartAlarmStreaming_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  StartAlarmStreaming* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, batch_id_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, batch_id_),
           offsetof(Impl_, resets_) -
               offsetof(Impl_, batch_id_) +
               sizeof(Impl_::resets_));

  // @@protoc_insertion_point(copy_constructor:alarms.v1.StartAlarmStreaming)
}
PROTOBUF_NDEBUG_INLINE StartAlarmStreaming::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        node_id_(arena) {}

inline void StartAlarmStreaming::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, batch_id_),
           0,
           offsetof(Impl_, resets_) -
               offsetof(Impl_, batch_id_) +
               sizeof(Impl_::resets_));
}
StartAlarmStreaming::~StartAlarmStreaming() {
  // @@protoc_insertion_point(destructor:alarms.v1.StartAlarmStreaming)
  SharedDtor(*this);
}
inline void StartAlarmStreaming::SharedDtor(MessageLite& self) {
  StartAlarmStreaming& this_ = static_cast<StartAlarmStreaming&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.node_id_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull StartAlarmStreaming_class_data_ =
        StartAlarmStreaming::InternalGenerateClassData_(StartAlarmStreaming_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
StartAlarmStreaming::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&StartAlarmStreaming_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(StartAlarmStreaming_class_data_.tc_table);
  return StartAlarmStreaming_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
StartAlarmStreaming::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&StartAlarmStreaming_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&StartAlarmStreaming_globals_));
  return StartAlarmStreaming_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const StartAlarmStreaming::ParseTableT_
    StartAlarmStreaming::_table_ =
        StartAlarmStreaming::InternalGenerateParseTable_(StartAlarmStreaming_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void StartAlarmStreaming::Clear() {
// @@protoc_insertion_point(message_clear_start:alarms.v1.StartAlarmStreaming)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _impl_.node_id_.ClearNonDefaultToEmpty();
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000001eU)) {
    ::memset(&_impl_.batch_id_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.resets_) -
        reinterpret_cast<char*>(&_impl_.batch_id_)) + sizeof(_impl_.resets_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL StartAlarmStreaming::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const StartAlarmStreaming& this_ = static_cast<const StartAlarmStreaming&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL StartAlarmStreaming::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const StartAlarmStreaming& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:alarms.v1.StartAlarmStreaming)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string node_id = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_node_id().empty()) {
      const ::std::string& _s = this_._internal_node_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.StartAlarmStreaming.node_id");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // uint64 batch_id = 2 [deprecated = true];
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (this_._internal_batch_id() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          2, this_._internal_batch_id(), target);
    }
  }

  // uint64 start_sequnce_id = 3 [deprecated = true];
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (this_._internal_start_sequnce_id() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_start_sequnce_id(), target);
    }
  }

  // bool resets = 4;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_resets() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          4, this_._internal_resets(), target);
    }
  }

  // uint64 version = 5;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_version() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          5, this_._internal_version(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:alarms.v1.StartAlarmStreaming)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t StartAlarmStreaming::ByteSizeLong(const MessageLite& base) {
  const StartAlarmStreaming& this_ = static_cast<const StartAlarmStreaming&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t StartAlarmStreaming::ByteSizeLong() const {
  const StartAlarmStreaming& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:alarms.v1.StartAlarmStreaming)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    // string node_id = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_node_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_node_id());
      }
    }
    // uint64 batch_id = 2 [deprecated = true];
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (this_._internal_batch_id() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_batch_id());
      }
    }
    // uint64 start_sequnce_id = 3 [deprecated = true];
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (this_._internal_start_sequnce_id() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_start_sequnce_id());
      }
    }
    // uint64 version = 5;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_version() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_version());
      }
    }
    // bool resets = 4;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_resets() != 0) {
        total_size += 2;
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void StartAlarmStreaming::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<StartAlarmStreaming*>(&to_msg);
  auto& from = static_cast<const StartAlarmStreaming&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:alarms.v1.StartAlarmStreaming)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_node_id().empty()) {
        _this->_internal_set_node_id(from._internal_node_id());
      } else {
        if (_this->_impl_.node_id_.IsDefault()) {
          _this->_internal_set_node_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (from._internal_batch_id() != 0) {
        _this->_impl_.batch_id_ = from._impl_.batch_id_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (from._internal_start_sequnce_id() != 0) {
        _this->_impl_.start_sequnce_id_ = from._impl_.start_sequnce_id_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_version() != 0) {
        _this->_impl_.version_ = from._impl_.version_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_resets() != 0) {
        _this->_impl_.resets_ = from._impl_.resets_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void StartAlarmStreaming::CopyFrom(const StartAlarmStreaming& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:alarms.v1.StartAlarmStreaming)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void StartAlarmStreaming::InternalSwap(StartAlarmStreaming* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.node_id_, &other->_impl_.node_id_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(StartAlarmStreaming, _impl_.resets_)
      + sizeof(StartAlarmStreaming::_impl_.resets_)
      - PROTOBUF_FIELD_OFFSET(StartAlarmStreaming, _impl_.batch_id_)>(
          reinterpret_cast<char*>(&_impl_.batch_id_),
          reinterpret_cast<char*>(&other->_impl_.batch_id_));
}

::google::protobuf::Metadata StartAlarmStreaming::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

SendAlarmCheckpoint::SendAlarmCheckpoint(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, SendAlarmCheckpoint_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:alarms.v1.SendAlarmCheckpoint)
}
PROTOBUF_NDEBUG_INLINE SendAlarmCheckpoint::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::alarms::v1::SendAlarmCheckpoint& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        node_id_(arena, from.node_id_),
        claim_id_(arena, from.claim_id_) {}

SendAlarmCheckpoint::SendAlarmCheckpoint(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const SendAlarmCheckpoint& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, SendAlarmCheckpoint_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SendAlarmCheckpoint* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  _impl_.version_ = from._impl_.version_;

  // @@protoc_insertion_point(copy_constructor:alarms.v1.SendAlarmCheckpoint)
}
PROTOBUF_NDEBUG_INLINE SendAlarmCheckpoint::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        node_id_(arena),
        claim_id_(arena) {}

inline void SendAlarmCheckpoint::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.version_ = {};
}
SendAlarmCheckpoint::~SendAlarmCheckpoint() {
  // @@protoc_insertion_point(destructor:alarms.v1.SendAlarmCheckpoint)
  SharedDtor(*this);
}
inline void SendAlarmCheckpoint::SharedDtor(MessageLite& self) {
  SendAlarmCheckpoint& this_ = static_cast<SendAlarmCheckpoint&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.node_id_.Destroy();
  this_._impl_.claim_id_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull SendAlarmCheckpoint_class_data_ =
        SendAlarmCheckpoint::InternalGenerateClassData_(SendAlarmCheckpoint_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
SendAlarmCheckpoint::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&SendAlarmCheckpoint_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(SendAlarmCheckpoint_class_data_.tc_table);
  return SendAlarmCheckpoint_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
SendAlarmCheckpoint::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&SendAlarmCheckpoint_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&SendAlarmCheckpoint_globals_));
  return SendAlarmCheckpoint_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const SendAlarmCheckpoint::ParseTableT_
    SendAlarmCheckpoint::_table_ =
        SendAlarmCheckpoint::InternalGenerateParseTable_(SendAlarmCheckpoint_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void SendAlarmCheckpoint::Clear() {
// @@protoc_insertion_point(message_clear_start:alarms.v1.SendAlarmCheckpoint)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.node_id_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.claim_id_.ClearNonDefaultToEmpty();
    }
  }
  _impl_.version_ = ::uint64_t{0u};
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL SendAlarmCheckpoint::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const SendAlarmCheckpoint& this_ = static_cast<const SendAlarmCheckpoint&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL SendAlarmCheckpoint::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const SendAlarmCheckpoint& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:alarms.v1.SendAlarmCheckpoint)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string node_id = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_node_id().empty()) {
      const ::std::string& _s = this_._internal_node_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.SendAlarmCheckpoint.node_id");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // string claim_id = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_claim_id().empty()) {
      const ::std::string& _s = this_._internal_claim_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.SendAlarmCheckpoint.claim_id");
      target = stream->WriteStringMaybeAliased(2, _s, target);
    }
  }

  // uint64 version = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (this_._internal_version() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_version(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:alarms.v1.SendAlarmCheckpoint)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t SendAlarmCheckpoint::ByteSizeLong(const MessageLite& base) {
  const SendAlarmCheckpoint& this_ = static_cast<const SendAlarmCheckpoint&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t SendAlarmCheckpoint::ByteSizeLong() const {
  const SendAlarmCheckpoint& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:alarms.v1.SendAlarmCheckpoint)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    // string node_id = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_node_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_node_id());
      }
    }
    // string claim_id = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_claim_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_claim_id());
      }
    }
    // uint64 version = 3;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (this_._internal_version() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_version());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void SendAlarmCheckpoint::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<SendAlarmCheckpoint*>(&to_msg);
  auto& from = static_cast<const SendAlarmCheckpoint&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:alarms.v1.SendAlarmCheckpoint)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_node_id().empty()) {
        _this->_internal_set_node_id(from._internal_node_id());
      } else {
        if (_this->_impl_.node_id_.IsDefault()) {
          _this->_internal_set_node_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_claim_id().empty()) {
        _this->_internal_set_claim_id(from._internal_claim_id());
      } else {
        if (_this->_impl_.claim_id_.IsDefault()) {
          _this->_internal_set_claim_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (from._internal_version() != 0) {
        _this->_impl_.version_ = from._impl_.version_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void SendAlarmCheckpoint::CopyFrom(const SendAlarmCheckpoint& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:alarms.v1.SendAlarmCheckpoint)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void SendAlarmCheckpoint::InternalSwap(SendAlarmCheckpoint* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.node_id_, &other->_impl_.node_id_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.claim_id_, &other->_impl_.claim_id_, arena);
  swap(_impl_.version_, other->_impl_.version_);
}

::google::protobuf::Metadata SendAlarmCheckpoint::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

AlarmCheckpoint::AlarmCheckpoint(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, AlarmCheckpoint_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:alarms.v1.AlarmCheckpoint)
}
PROTOBUF_NDEBUG_INLINE AlarmCheckpoint::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::alarms::v1::AlarmCheckpoint& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        node_id_(arena, from.node_id_),
        claim_id_(arena, from.claim_id_),
        checksum_(arena, from.checksum_) {}

AlarmCheckpoint::AlarmCheckpoint(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const AlarmCheckpoint& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, AlarmCheckpoint_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  AlarmCheckpoint* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:alarms.v1.AlarmCheckpoint)
}
PROTOBUF_NDEBUG_INLINE AlarmCheckpoint::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        node_id_(arena),
        claim_id_(arena),
        checksum_(arena) {}

inline void AlarmCheckpoint::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
AlarmCheckpoint::~AlarmCheckpoint() {
  // @@protoc_insertion_point(destructor:alarms.v1.AlarmCheckpoint)
  SharedDtor(*this);
}
inline void AlarmCheckpoint::SharedDtor(MessageLite& self) {
  AlarmCheckpoint& this_ = static_cast<AlarmCheckpoint&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.node_id_.Destroy();
  this_._impl_.claim_id_.Destroy();
  this_._impl_.checksum_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull AlarmCheckpoint_class_data_ =
        AlarmCheckpoint::InternalGenerateClassData_(AlarmCheckpoint_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
AlarmCheckpoint::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&AlarmCheckpoint_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(AlarmCheckpoint_class_data_.tc_table);
  return AlarmCheckpoint_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
AlarmCheckpoint::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&AlarmCheckpoint_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&AlarmCheckpoint_globals_));
  return AlarmCheckpoint_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const AlarmCheckpoint::ParseTableT_
    AlarmCheckpoint::_table_ =
        AlarmCheckpoint::InternalGenerateParseTable_(AlarmCheckpoint_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void AlarmCheckpoint::Clear() {
// @@protoc_insertion_point(message_clear_start:alarms.v1.AlarmCheckpoint)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.node_id_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.claim_id_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.checksum_.ClearNonDefaultToEmpty();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL AlarmCheckpoint::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const AlarmCheckpoint& this_ = static_cast<const AlarmCheckpoint&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL AlarmCheckpoint::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const AlarmCheckpoint& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:alarms.v1.AlarmCheckpoint)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string node_id = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_node_id().empty()) {
      const ::std::string& _s = this_._internal_node_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmCheckpoint.node_id");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // string claim_id = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_claim_id().empty()) {
      const ::std::string& _s = this_._internal_claim_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmCheckpoint.claim_id");
      target = stream->WriteStringMaybeAliased(2, _s, target);
    }
  }

  // bytes checksum = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (!this_._internal_checksum().empty()) {
      const ::std::string& _s = this_._internal_checksum();
      target = stream->WriteBytesMaybeAliased(3, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:alarms.v1.AlarmCheckpoint)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t AlarmCheckpoint::ByteSizeLong(const MessageLite& base) {
  const AlarmCheckpoint& this_ = static_cast<const AlarmCheckpoint&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t AlarmCheckpoint::ByteSizeLong() const {
  const AlarmCheckpoint& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:alarms.v1.AlarmCheckpoint)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    // string node_id = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_node_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_node_id());
      }
    }
    // string claim_id = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_claim_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_claim_id());
      }
    }
    // bytes checksum = 3;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!this_._internal_checksum().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::BytesSize(
                                        this_._internal_checksum());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void AlarmCheckpoint::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<AlarmCheckpoint*>(&to_msg);
  auto& from = static_cast<const AlarmCheckpoint&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:alarms.v1.AlarmCheckpoint)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_node_id().empty()) {
        _this->_internal_set_node_id(from._internal_node_id());
      } else {
        if (_this->_impl_.node_id_.IsDefault()) {
          _this->_internal_set_node_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_claim_id().empty()) {
        _this->_internal_set_claim_id(from._internal_claim_id());
      } else {
        if (_this->_impl_.claim_id_.IsDefault()) {
          _this->_internal_set_claim_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!from._internal_checksum().empty()) {
        _this->_internal_set_checksum(from._internal_checksum());
      } else {
        if (_this->_impl_.checksum_.IsDefault()) {
          _this->_internal_set_checksum("");
        }
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void AlarmCheckpoint::CopyFrom(const AlarmCheckpoint& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:alarms.v1.AlarmCheckpoint)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void AlarmCheckpoint::InternalSwap(AlarmCheckpoint* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.node_id_, &other->_impl_.node_id_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.claim_id_, &other->_impl_.claim_id_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.checksum_, &other->_impl_.checksum_, arena);
}

::google::protobuf::Metadata AlarmCheckpoint::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

AlarmLogEntry::AlarmLogEntry(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, AlarmLogEntry_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:alarms.v1.AlarmLogEntry)
}
PROTOBUF_NDEBUG_INLINE AlarmLogEntry::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::alarms::v1::AlarmLogEntry& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        node_id_(arena, from.node_id_),
        claim_id_(arena, from.claim_id_),
        chart_(arena, from.chart_),
        name_(arena, from.name_),
        family_(arena, from.family_),
        config_hash_(arena, from.config_hash_),
        timezone_(arena, from.timezone_),
        exec_path_(arena, from.exec_path_),
        conf_source_(arena, from.conf_source_),
        command_(arena, from.command_),
        value_string_(arena, from.value_string_),
        old_value_string_(arena, from.old_value_string_),
        rendered_info_(arena, from.rendered_info_),
        chart_context_(arena, from.chart_context_),
        transition_id_(arena, from.transition_id_),
        chart_name_(arena, from.chart_name_),
        summary_(arena, from.summary_) {}

AlarmLogEntry::AlarmLogEntry(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const AlarmLogEntry& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, AlarmLogEntry_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  AlarmLogEntry* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, batch_id_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, batch_id_),
           offsetof(Impl_, event_id_) -
               offsetof(Impl_, batch_id_) +
               sizeof(Impl_::event_id_));
  _impl_.alert_version_ = from._impl_.alert_version_;

  // @@protoc_insertion_point(copy_constructor:alarms.v1.AlarmLogEntry)
}
PROTOBUF_NDEBUG_INLINE AlarmLogEntry::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        node_id_(arena),
        claim_id_(arena),
        chart_(arena),
        name_(arena),
        family_(arena),
        config_hash_(arena),
        timezone_(arena),
        exec_path_(arena),
        conf_source_(arena),
        command_(arena),
        value_string_(arena),
        old_value_string_(arena),
        rendered_info_(arena),
        chart_context_(arena),
        transition_id_(arena),
        chart_name_(arena),
        summary_(arena) {}

inline void AlarmLogEntry::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, batch_id_),
           0,
           offsetof(Impl_, event_id_) -
               offsetof(Impl_, batch_id_) +
               sizeof(Impl_::event_id_));
  _impl_.alert_version_ = {};
}
AlarmLogEntry::~AlarmLogEntry() {
  // @@protoc_insertion_point(destructor:alarms.v1.AlarmLogEntry)
  SharedDtor(*this);
}
inline void AlarmLogEntry::SharedDtor(MessageLite& self) {
  AlarmLogEntry& this_ = static_cast<AlarmLogEntry&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.node_id_.Destroy();
  this_._impl_.claim_id_.Destroy();
  this_._impl_.chart_.Destroy();
  this_._impl_.name_.Destroy();
  this_._impl_.family_.Destroy();
  this_._impl_.config_hash_.Destroy();
  this_._impl_.timezone_.Destroy();
  this_._impl_.exec_path_.Destroy();
  this_._impl_.conf_source_.Destroy();
  this_._impl_.command_.Destroy();
  this_._impl_.value_string_.Destroy();
  this_._impl_.old_value_string_.Destroy();
  this_._impl_.rendered_info_.Destroy();
  this_._impl_.chart_context_.Destroy();
  this_._impl_.transition_id_.Destroy();
  this_._impl_.chart_name_.Destroy();
  this_._impl_.summary_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull AlarmLogEntry_class_data_ =
        AlarmLogEntry::InternalGenerateClassData_(AlarmLogEntry_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
AlarmLogEntry::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&AlarmLogEntry_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(AlarmLogEntry_class_data_.tc_table);
  return AlarmLogEntry_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
AlarmLogEntry::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&AlarmLogEntry_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&AlarmLogEntry_globals_));
  return AlarmLogEntry_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const AlarmLogEntry::ParseTableT_
    AlarmLogEntry::_table_ =
        AlarmLogEntry::InternalGenerateParseTable_(AlarmLogEntry_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void AlarmLogEntry::Clear() {
// @@protoc_insertion_point(message_clear_start:alarms.v1.AlarmLogEntry)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.node_id_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.claim_id_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.chart_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _impl_.name_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      _impl_.family_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      _impl_.config_hash_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      _impl_.timezone_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      _impl_.exec_path_.ClearNonDefaultToEmpty();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00007f00U)) {
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      _impl_.conf_source_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      _impl_.command_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000400U)) {
      _impl_.value_string_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000800U)) {
      _impl_.old_value_string_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00001000U)) {
      _impl_.rendered_info_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00002000U)) {
      _impl_.chart_context_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00004000U)) {
      _impl_.transition_id_.ClearNonDefaultToEmpty();
    }
  }
  _impl_.batch_id_ = ::uint64_t{0u};
  if (BatchCheckHasBit(cached_has_bits, 0x00ff0000U)) {
    ::memset(&_impl_.sequence_id_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.delay_up_to_timestamp_) -
        reinterpret_cast<char*>(&_impl_.sequence_id_)) + sizeof(_impl_.delay_up_to_timestamp_));
  }
  if (BatchCheckHasBit(cached_has_bits, 0xff000000U)) {
    ::memset(&_impl_.last_repeat_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.event_id_) -
        reinterpret_cast<char*>(&_impl_.last_repeat_)) + sizeof(_impl_.event_id_));
    if (CheckHasBit(cached_has_bits, 0x80000000U)) {
      _impl_.chart_name_.ClearNonDefaultToEmpty();
    }
  }
  cached_has_bits = _impl_._has_bits_[1];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _impl_.summary_.ClearNonDefaultToEmpty();
  }
  _impl_.alert_version_ = ::uint64_t{0u};
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL AlarmLogEntry::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const AlarmLogEntry& this_ = static_cast<const AlarmLogEntry&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL AlarmLogEntry::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const AlarmLogEntry& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:alarms.v1.AlarmLogEntry)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string node_id = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_node_id().empty()) {
      const ::std::string& _s = this_._internal_node_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmLogEntry.node_id");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // string claim_id = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_claim_id().empty()) {
      const ::std::string& _s = this_._internal_claim_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmLogEntry.claim_id");
      target = stream->WriteStringMaybeAliased(2, _s, target);
    }
  }

  // string chart = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (!this_._internal_chart().empty()) {
      const ::std::string& _s = this_._internal_chart();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmLogEntry.chart");
      target = stream->WriteStringMaybeAliased(3, _s, target);
    }
  }

  // string name = 4;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (!this_._internal_name().empty()) {
      const ::std::string& _s = this_._internal_name();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmLogEntry.name");
      target = stream->WriteStringMaybeAliased(4, _s, target);
    }
  }

  // string family = 5 [deprecated = true];
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (!this_._internal_family().empty()) {
      const ::std::string& _s = this_._internal_family();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmLogEntry.family");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // uint64 batch_id = 6 [deprecated = true];
  if (CheckHasBit(cached_has_bits, 0x00008000U)) {
    if (this_._internal_batch_id() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          6, this_._internal_batch_id(), target);
    }
  }

  // uint64 sequence_id = 7 [deprecated = true];
  if (CheckHasBit(cached_has_bits, 0x00010000U)) {
    if (this_._internal_sequence_id() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          7, this_._internal_sequence_id(), target);
    }
  }

  // uint64 when = 8;
  if (CheckHasBit(cached_has_bits, 0x00020000U)) {
    if (this_._internal_when() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          8, this_._internal_when(), target);
    }
  }

  // string config_hash = 9;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (!this_._internal_config_hash().empty()) {
      const ::std::string& _s = this_._internal_config_hash();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmLogEntry.config_hash");
      target = stream->WriteStringMaybeAliased(9, _s, target);
    }
  }

  // int32 utc_offset = 10;
  if (CheckHasBit(cached_has_bits, 0x00040000U)) {
    if (this_._internal_utc_offset() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<10>(
              stream, this_._internal_utc_offset(), target);
    }
  }

  // string timezone = 11;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (!this_._internal_timezone().empty()) {
      const ::std::string& _s = this_._internal_timezone();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmLogEntry.timezone");
      target = stream->WriteStringMaybeAliased(11, _s, target);
    }
  }

  // string exec_path = 12;
  if (CheckHasBit(cached_has_bits, 0x00000080U)) {
    if (!this_._internal_exec_path().empty()) {
      const ::std::string& _s = this_._internal_exec_path();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmLogEntry.exec_path");
      target = stream->WriteStringMaybeAliased(12, _s, target);
    }
  }

  // string conf_source = 13;
  if (CheckHasBit(cached_has_bits, 0x00000100U)) {
    if (!this_._internal_conf_source().empty()) {
      const ::std::string& _s = this_._internal_conf_source();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmLogEntry.conf_source");
      target = stream->WriteStringMaybeAliased(13, _s, target);
    }
  }

  // string command = 14;
  if (CheckHasBit(cached_has_bits, 0x00000200U)) {
    if (!this_._internal_command().empty()) {
      const ::std::string& _s = this_._internal_command();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmLogEntry.command");
      target = stream->WriteStringMaybeAliased(14, _s, target);
    }
  }

  // uint32 duration = 15;
  if (CheckHasBit(cached_has_bits, 0x00080000U)) {
    if (this_._internal_duration() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
          15, this_._internal_duration(), target);
    }
  }

  // uint32 non_clear_duration = 16;
  if (CheckHasBit(cached_has_bits, 0x00100000U)) {
    if (this_._internal_non_clear_duration() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
          16, this_._internal_non_clear_duration(), target);
    }
  }

  // .alarms.v1.AlarmStatus status = 17;
  if (CheckHasBit(cached_has_bits, 0x00200000U)) {
    if (this_._internal_status() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteEnumToArray(
          17, this_._internal_status(), target);
    }
  }

  // .alarms.v1.AlarmStatus old_status = 18;
  if (CheckHasBit(cached_has_bits, 0x02000000U)) {
    if (this_._internal_old_status() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteEnumToArray(
          18, this_._internal_old_status(), target);
    }
  }

  // uint64 delay = 19;
  if (CheckHasBit(cached_has_bits, 0x00400000U)) {
    if (this_._internal_delay() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          19, this_._internal_delay(), target);
    }
  }

  // uint64 delay_up_to_timestamp = 20;
  if (CheckHasBit(cached_has_bits, 0x00800000U)) {
    if (this_._internal_delay_up_to_timestamp() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          20, this_._internal_delay_up_to_timestamp(), target);
    }
  }

  // uint64 last_repeat = 21;
  if (CheckHasBit(cached_has_bits, 0x01000000U)) {
    if (this_._internal_last_repeat() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          21, this_._internal_last_repeat(), target);
    }
  }

  // bool silenced = 22;
  if (CheckHasBit(cached_has_bits, 0x04000000U)) {
    if (this_._internal_silenced() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          22, this_._internal_silenced(), target);
    }
  }

  // string value_string = 23;
  if (CheckHasBit(cached_has_bits, 0x00000400U)) {
    if (!this_._internal_value_string().empty()) {
      const ::std::string& _s = this_._internal_value_string();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmLogEntry.value_string");
      target = stream->WriteStringMaybeAliased(23, _s, target);
    }
  }

  // string old_value_string = 24;
  if (CheckHasBit(cached_has_bits, 0x00000800U)) {
    if (!this_._internal_old_value_string().empty()) {
      const ::std::string& _s = this_._internal_old_value_string();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmLogEntry.old_value_string");
      target = stream->WriteStringMaybeAliased(24, _s, target);
    }
  }

  // double value = 25;
  if (CheckHasBit(cached_has_bits, 0x10000000U)) {
    if (::absl::bit_cast<::uint64_t>(this_._internal_value()) != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteDoubleToArray(
          25, this_._internal_value(), target);
    }
  }

  // double old_value = 26;
  if (CheckHasBit(cached_has_bits, 0x20000000U)) {
    if (::absl::bit_cast<::uint64_t>(this_._internal_old_value()) != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteDoubleToArray(
          26, this_._internal_old_value(), target);
    }
  }

  // bool updated = 27;
  if (CheckHasBit(cached_has_bits, 0x08000000U)) {
    if (this_._internal_updated() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          27, this_._internal_updated(), target);
    }
  }

  // string rendered_info = 28;
  if (CheckHasBit(cached_has_bits, 0x00001000U)) {
    if (!this_._internal_rendered_info().empty()) {
      const ::std::string& _s = this_._internal_rendered_info();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmLogEntry.rendered_info");
      target = stream->WriteStringMaybeAliased(28, _s, target);
    }
  }

  // string chart_context = 29;
  if (CheckHasBit(cached_has_bits, 0x00002000U)) {
    if (!this_._internal_chart_context().empty()) {
      const ::std::string& _s = this_._internal_chart_context();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmLogEntry.chart_context");
      target = stream->WriteStringMaybeAliased(29, _s, target);
    }
  }

  // uint64 event_id = 30;
  if (CheckHasBit(cached_has_bits, 0x40000000U)) {
    if (this_._internal_event_id() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          30, this_._internal_event_id(), target);
    }
  }

  // string transition_id = 31;
  if (CheckHasBit(cached_has_bits, 0x00004000U)) {
    if (!this_._internal_transition_id().empty()) {
      const ::std::string& _s = this_._internal_transition_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmLogEntry.transition_id");
      target = stream->WriteStringMaybeAliased(31, _s, target);
    }
  }

  // string chart_name = 32;
  if (CheckHasBit(cached_has_bits, 0x80000000U)) {
    if (!this_._internal_chart_name().empty()) {
      const ::std::string& _s = this_._internal_chart_name();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmLogEntry.chart_name");
      target = stream->WriteStringMaybeAliased(32, _s, target);
    }
  }

  cached_has_bits = this_._impl_._has_bits_[1];
  // string summary = 33;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_summary().empty()) {
      const ::std::string& _s = this_._internal_summary();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmLogEntry.summary");
      target = stream->WriteStringMaybeAliased(33, _s, target);
    }
  }

  // uint64 alert_version = 34;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (this_._internal_alert_version() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          34, this_._internal_alert_version(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:alarms.v1.AlarmLogEntry)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t AlarmLogEntry::ByteSizeLong(const MessageLite& base) {
  const AlarmLogEntry& this_ = static_cast<const AlarmLogEntry&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t AlarmLogEntry::ByteSizeLong() const {
  const AlarmLogEntry& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:alarms.v1.AlarmLogEntry)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    // string node_id = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_node_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_node_id());
      }
    }
    // string claim_id = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_claim_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_claim_id());
      }
    }
    // string chart = 3;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!this_._internal_chart().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_chart());
      }
    }
    // string name = 4;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!this_._internal_name().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_name());
      }
    }
    // string family = 5 [deprecated = true];
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (!this_._internal_family().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_family());
      }
    }
    // string config_hash = 9;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (!this_._internal_config_hash().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_config_hash());
      }
    }
    // string timezone = 11;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (!this_._internal_timezone().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_timezone());
      }
    }
    // string exec_path = 12;
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (!this_._internal_exec_path().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_exec_path());
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000ff00U)) {
    // string conf_source = 13;
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (!this_._internal_conf_source().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_conf_source());
      }
    }
    // string command = 14;
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      if (!this_._internal_command().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_command());
      }
    }
    // string value_string = 23;
    if (CheckHasBit(cached_has_bits, 0x00000400U)) {
      if (!this_._internal_value_string().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_value_string());
      }
    }
    // string old_value_string = 24;
    if (CheckHasBit(cached_has_bits, 0x00000800U)) {
      if (!this_._internal_old_value_string().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_old_value_string());
      }
    }
    // string rendered_info = 28;
    if (CheckHasBit(cached_has_bits, 0x00001000U)) {
      if (!this_._internal_rendered_info().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_rendered_info());
      }
    }
    // string chart_context = 29;
    if (CheckHasBit(cached_has_bits, 0x00002000U)) {
      if (!this_._internal_chart_context().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_chart_context());
      }
    }
    // string transition_id = 31;
    if (CheckHasBit(cached_has_bits, 0x00004000U)) {
      if (!this_._internal_transition_id().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_transition_id());
      }
    }
    // uint64 batch_id = 6 [deprecated = true];
    if (CheckHasBit(cached_has_bits, 0x00008000U)) {
      if (this_._internal_batch_id() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_batch_id());
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00ff0000U)) {
    // uint64 sequence_id = 7 [deprecated = true];
    if (CheckHasBit(cached_has_bits, 0x00010000U)) {
      if (this_._internal_sequence_id() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sequence_id());
      }
    }
    // uint64 when = 8;
    if (CheckHasBit(cached_has_bits, 0x00020000U)) {
      if (this_._internal_when() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_when());
      }
    }
    // int32 utc_offset = 10;
    if (CheckHasBit(cached_has_bits, 0x00040000U)) {
      if (this_._internal_utc_offset() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_utc_offset());
      }
    }
    // uint32 duration = 15;
    if (CheckHasBit(cached_has_bits, 0x00080000U)) {
      if (this_._internal_duration() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
            this_._internal_duration());
      }
    }
    // uint32 non_clear_duration = 16;
    if (CheckHasBit(cached_has_bits, 0x00100000U)) {
      if (this_._internal_non_clear_duration() != 0) {
        total_size += 2 + ::_pbi::WireFormatLite::UInt32Size(
                                        this_._internal_non_clear_duration());
      }
    }
    // .alarms.v1.AlarmStatus status = 17;
    if (CheckHasBit(cached_has_bits, 0x00200000U)) {
      if (this_._internal_status() != 0) {
        total_size += 2 +
                      ::_pbi::WireFormatLite::EnumSize(this_._internal_status());
      }
    }
    // uint64 delay = 19;
    if (CheckHasBit(cached_has_bits, 0x00400000U)) {
      if (this_._internal_delay() != 0) {
        total_size += 2 + ::_pbi::WireFormatLite::UInt64Size(
                                        this_._internal_delay());
      }
    }
    // uint64 delay_up_to_timestamp = 20;
    if (CheckHasBit(cached_has_bits, 0x00800000U)) {
      if (this_._internal_delay_up_to_timestamp() != 0) {
        total_size += 2 + ::_pbi::WireFormatLite::UInt64Size(
                                        this_._internal_delay_up_to_timestamp());
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0xff000000U)) {
    // uint64 last_repeat = 21;
    if (CheckHasBit(cached_has_bits, 0x01000000U)) {
      if (this_._internal_last_repeat() != 0) {
        total_size += 2 + ::_pbi::WireFormatLite::UInt64Size(
                                        this_._internal_last_repeat());
      }
    }
    // .alarms.v1.AlarmStatus old_status = 18;
    if (CheckHasBit(cached_has_bits, 0x02000000U)) {
      if (this_._internal_old_status() != 0) {
        total_size += 2 +
                      ::_pbi::WireFormatLite::EnumSize(this_._internal_old_status());
      }
    }
    // bool silenced = 22;
    if (CheckHasBit(cached_has_bits, 0x04000000U)) {
      if (this_._internal_silenced() != 0) {
        total_size += 3;
      }
    }
    // bool updated = 27;
    if (CheckHasBit(cached_has_bits, 0x08000000U)) {
      if (this_._internal_updated() != 0) {
        total_size += 3;
      }
    }
    // double value = 25;
    if (CheckHasBit(cached_has_bits, 0x10000000U)) {
      if (::absl::bit_cast<::uint64_t>(this_._internal_value()) != 0) {
        total_size += 10;
      }
    }
    // double old_value = 26;
    if (CheckHasBit(cached_has_bits, 0x20000000U)) {
      if (::absl::bit_cast<::uint64_t>(this_._internal_old_value()) != 0) {
        total_size += 10;
      }
    }
    // uint64 event_id = 30;
    if (CheckHasBit(cached_has_bits, 0x40000000U)) {
      if (this_._internal_event_id() != 0) {
        total_size += 2 + ::_pbi::WireFormatLite::UInt64Size(
                                        this_._internal_event_id());
      }
    }
    // string chart_name = 32;
    if (CheckHasBit(cached_has_bits, 0x80000000U)) {
      if (!this_._internal_chart_name().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_chart_name());
      }
    }
  }
  cached_has_bits = this_._impl_._has_bits_[1];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    // string summary = 33;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_summary().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_summary());
      }
    }
    // uint64 alert_version = 34;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (this_._internal_alert_version() != 0) {
        total_size += 2 + ::_pbi::WireFormatLite::UInt64Size(
                                        this_._internal_alert_version());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void AlarmLogEntry::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<AlarmLogEntry*>(&to_msg);
  auto& from = static_cast<const AlarmLogEntry&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:alarms.v1.AlarmLogEntry)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_node_id().empty()) {
        _this->_internal_set_node_id(from._internal_node_id());
      } else {
        if (_this->_impl_.node_id_.IsDefault()) {
          _this->_internal_set_node_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_claim_id().empty()) {
        _this->_internal_set_claim_id(from._internal_claim_id());
      } else {
        if (_this->_impl_.claim_id_.IsDefault()) {
          _this->_internal_set_claim_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!from._internal_chart().empty()) {
        _this->_internal_set_chart(from._internal_chart());
      } else {
        if (_this->_impl_.chart_.IsDefault()) {
          _this->_internal_set_chart("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!from._internal_name().empty()) {
        _this->_internal_set_name(from._internal_name());
      } else {
        if (_this->_impl_.name_.IsDefault()) {
          _this->_internal_set_name("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (!from._internal_family().empty()) {
        _this->_internal_set_family(from._internal_family());
      } else {
        if (_this->_impl_.family_.IsDefault()) {
          _this->_internal_set_family("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (!from._internal_config_hash().empty()) {
        _this->_internal_set_config_hash(from._internal_config_hash());
      } else {
        if (_this->_impl_.config_hash_.IsDefault()) {
          _this->_internal_set_config_hash("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (!from._internal_timezone().empty()) {
        _this->_internal_set_timezone(from._internal_timezone());
      } else {
        if (_this->_impl_.timezone_.IsDefault()) {
          _this->_internal_set_timezone("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (!from._internal_exec_path().empty()) {
        _this->_internal_set_exec_path(from._internal_exec_path());
      } else {
        if (_this->_impl_.exec_path_.IsDefault()) {
          _this->_internal_set_exec_path("");
        }
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000ff00U)) {
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (!from._internal_conf_source().empty()) {
        _this->_internal_set_conf_source(from._internal_conf_source());
      } else {
        if (_this->_impl_.conf_source_.IsDefault()) {
          _this->_internal_set_conf_source("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      if (!from._internal_command().empty()) {
        _this->_internal_set_command(from._internal_command());
      } else {
        if (_this->_impl_.command_.IsDefault()) {
          _this->_internal_set_command("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000400U)) {
      if (!from._internal_value_string().empty()) {
        _this->_internal_set_value_string(from._internal_value_string());
      } else {
        if (_this->_impl_.value_string_.IsDefault()) {
          _this->_internal_set_value_string("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000800U)) {
      if (!from._internal_old_value_string().empty()) {
        _this->_internal_set_old_value_string(from._internal_old_value_string());
      } else {
        if (_this->_impl_.old_value_string_.IsDefault()) {
          _this->_internal_set_old_value_string("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00001000U)) {
      if (!from._internal_rendered_info().empty()) {
        _this->_internal_set_rendered_info(from._internal_rendered_info());
      } else {
        if (_this->_impl_.rendered_info_.IsDefault()) {
          _this->_internal_set_rendered_info("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00002000U)) {
      if (!from._internal_chart_context().empty()) {
        _this->_internal_set_chart_context(from._internal_chart_context());
      } else {
        if (_this->_impl_.chart_context_.IsDefault()) {
          _this->_internal_set_chart_context("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00004000U)) {
      if (!from._internal_transition_id().empty()) {
        _this->_internal_set_transition_id(from._internal_transition_id());
      } else {
        if (_this->_impl_.transition_id_.IsDefault()) {
          _this->_internal_set_transition_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00008000U)) {
      if (from._internal_batch_id() != 0) {
        _this->_impl_.batch_id_ = from._impl_.batch_id_;
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00ff0000U)) {
    if (CheckHasBit(cached_has_bits, 0x00010000U)) {
      if (from._internal_sequence_id() != 0) {
        _this->_impl_.sequence_id_ = from._impl_.sequence_id_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00020000U)) {
      if (from._internal_when() != 0) {
        _this->_impl_.when_ = from._impl_.when_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00040000U)) {
      if (from._internal_utc_offset() != 0) {
        _this->_impl_.utc_offset_ = from._impl_.utc_offset_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00080000U)) {
      if (from._internal_duration() != 0) {
        _this->_impl_.duration_ = from._impl_.duration_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00100000U)) {
      if (from._internal_non_clear_duration() != 0) {
        _this->_impl_.non_clear_duration_ = from._impl_.non_clear_duration_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00200000U)) {
      if (from._internal_status() != 0) {
        _this->_impl_.status_ = from._impl_.status_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00400000U)) {
      if (from._internal_delay() != 0) {
        _this->_impl_.delay_ = from._impl_.delay_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00800000U)) {
      if (from._internal_delay_up_to_timestamp() != 0) {
        _this->_impl_.delay_up_to_timestamp_ = from._impl_.delay_up_to_timestamp_;
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0xff000000U)) {
    if (CheckHasBit(cached_has_bits, 0x01000000U)) {
      if (from._internal_last_repeat() != 0) {
        _this->_impl_.last_repeat_ = from._impl_.last_repeat_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x02000000U)) {
      if (from._internal_old_status() != 0) {
        _this->_impl_.old_status_ = from._impl_.old_status_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x04000000U)) {
      if (from._internal_silenced() != 0) {
        _this->_impl_.silenced_ = from._impl_.silenced_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x08000000U)) {
      if (from._internal_updated() != 0) {
        _this->_impl_.updated_ = from._impl_.updated_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x10000000U)) {
      if (::absl::bit_cast<::uint64_t>(from._internal_value()) != 0) {
        _this->_impl_.value_ = from._impl_.value_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x20000000U)) {
      if (::absl::bit_cast<::uint64_t>(from._internal_old_value()) != 0) {
        _this->_impl_.old_value_ = from._impl_.old_value_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x40000000U)) {
      if (from._internal_event_id() != 0) {
        _this->_impl_.event_id_ = from._impl_.event_id_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x80000000U)) {
      if (!from._internal_chart_name().empty()) {
        _this->_internal_set_chart_name(from._internal_chart_name());
      } else {
        if (_this->_impl_.chart_name_.IsDefault()) {
          _this->_internal_set_chart_name("");
        }
      }
    }
  }
  cached_has_bits = from._impl_._has_bits_[1];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_summary().empty()) {
        _this->_internal_set_summary(from._internal_summary());
      } else {
        if (_this->_impl_.summary_.IsDefault()) {
          _this->_internal_set_summary("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (from._internal_alert_version() != 0) {
        _this->_impl_.alert_version_ = from._impl_.alert_version_;
      }
    }
  }
  _this->_impl_._has_bits_.Or(from._impl_._has_bits_);
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void AlarmLogEntry::CopyFrom(const AlarmLogEntry& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:alarms.v1.AlarmLogEntry)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void AlarmLogEntry::InternalSwap(AlarmLogEntry* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  swap(_impl_._has_bits_[1], other->_impl_._has_bits_[1]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.node_id_, &other->_impl_.node_id_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.claim_id_, &other->_impl_.claim_id_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.chart_, &other->_impl_.chart_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.name_, &other->_impl_.name_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.family_, &other->_impl_.family_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.config_hash_, &other->_impl_.config_hash_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.timezone_, &other->_impl_.timezone_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.exec_path_, &other->_impl_.exec_path_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.conf_source_, &other->_impl_.conf_source_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.command_, &other->_impl_.command_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.value_string_, &other->_impl_.value_string_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.old_value_string_, &other->_impl_.old_value_string_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.rendered_info_, &other->_impl_.rendered_info_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.chart_context_, &other->_impl_.chart_context_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.transition_id_, &other->_impl_.transition_id_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.event_id_)
      + sizeof(AlarmLogEntry::_impl_.event_id_)
      - PROTOBUF_FIELD_OFFSET(AlarmLogEntry, _impl_.batch_id_)>(
          reinterpret_cast<char*>(&_impl_.batch_id_),
          reinterpret_cast<char*>(&other->_impl_.batch_id_));
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.chart_name_, &other->_impl_.chart_name_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.summary_, &other->_impl_.summary_, arena);
  swap(_impl_.alert_version_, other->_impl_.alert_version_);
}

::google::protobuf::Metadata AlarmLogEntry::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

SendAlarmSnapshot::SendAlarmSnapshot(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, SendAlarmSnapshot_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:alarms.v1.SendAlarmSnapshot)
}
PROTOBUF_NDEBUG_INLINE SendAlarmSnapshot::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::alarms::v1::SendAlarmSnapshot& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        node_id_(arena, from.node_id_),
        claim_id_(arena, from.claim_id_),
        snapshot_uuid_(arena, from.snapshot_uuid_) {}

SendAlarmSnapshot::SendAlarmSnapshot(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const SendAlarmSnapshot& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, SendAlarmSnapshot_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SendAlarmSnapshot* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, snapshot_id_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, snapshot_id_),
           offsetof(Impl_, sequence_id_) -
               offsetof(Impl_, snapshot_id_) +
               sizeof(Impl_::sequence_id_));

  // @@protoc_insertion_point(copy_constructor:alarms.v1.SendAlarmSnapshot)
}
PROTOBUF_NDEBUG_INLINE SendAlarmSnapshot::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        node_id_(arena),
        claim_id_(arena),
        snapshot_uuid_(arena) {}

inline void SendAlarmSnapshot::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, snapshot_id_),
           0,
           offsetof(Impl_, sequence_id_) -
               offsetof(Impl_, snapshot_id_) +
               sizeof(Impl_::sequence_id_));
}
SendAlarmSnapshot::~SendAlarmSnapshot() {
  // @@protoc_insertion_point(destructor:alarms.v1.SendAlarmSnapshot)
  SharedDtor(*this);
}
inline void SendAlarmSnapshot::SharedDtor(MessageLite& self) {
  SendAlarmSnapshot& this_ = static_cast<SendAlarmSnapshot&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.node_id_.Destroy();
  this_._impl_.claim_id_.Destroy();
  this_._impl_.snapshot_uuid_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull SendAlarmSnapshot_class_data_ =
        SendAlarmSnapshot::InternalGenerateClassData_(SendAlarmSnapshot_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
SendAlarmSnapshot::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&SendAlarmSnapshot_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(SendAlarmSnapshot_class_data_.tc_table);
  return SendAlarmSnapshot_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
SendAlarmSnapshot::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&SendAlarmSnapshot_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&SendAlarmSnapshot_globals_));
  return SendAlarmSnapshot_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const SendAlarmSnapshot::ParseTableT_
    SendAlarmSnapshot::_table_ =
        SendAlarmSnapshot::InternalGenerateParseTable_(SendAlarmSnapshot_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void SendAlarmSnapshot::Clear() {
// @@protoc_insertion_point(message_clear_start:alarms.v1.SendAlarmSnapshot)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.node_id_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.claim_id_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.snapshot_uuid_.ClearNonDefaultToEmpty();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000018U)) {
    ::memset(&_impl_.snapshot_id_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.sequence_id_) -
        reinterpret_cast<char*>(&_impl_.snapshot_id_)) + sizeof(_impl_.sequence_id_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL SendAlarmSnapshot::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const SendAlarmSnapshot& this_ = static_cast<const SendAlarmSnapshot&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL SendAlarmSnapshot::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const SendAlarmSnapshot& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:alarms.v1.SendAlarmSnapshot)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string node_id = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_node_id().empty()) {
      const ::std::string& _s = this_._internal_node_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.SendAlarmSnapshot.node_id");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // string claim_id = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_claim_id().empty()) {
      const ::std::string& _s = this_._internal_claim_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.SendAlarmSnapshot.claim_id");
      target = stream->WriteStringMaybeAliased(2, _s, target);
    }
  }

  // uint64 snapshot_id = 3 [deprecated = true];
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (this_._internal_snapshot_id() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_snapshot_id(), target);
    }
  }

  // uint64 sequence_id = 4 [deprecated = true];
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_sequence_id() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          4, this_._internal_sequence_id(), target);
    }
  }

  // string snapshot_uuid = 5;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (!this_._internal_snapshot_uuid().empty()) {
      const ::std::string& _s = this_._internal_snapshot_uuid();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.SendAlarmSnapshot.snapshot_uuid");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:alarms.v1.SendAlarmSnapshot)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t SendAlarmSnapshot::ByteSizeLong(const MessageLite& base) {
  const SendAlarmSnapshot& this_ = static_cast<const SendAlarmSnapshot&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t SendAlarmSnapshot::ByteSizeLong() const {
  const SendAlarmSnapshot& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:alarms.v1.SendAlarmSnapshot)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    // string node_id = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_node_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_node_id());
      }
    }
    // string claim_id = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_claim_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_claim_id());
      }
    }
    // string snapshot_uuid = 5;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!this_._internal_snapshot_uuid().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_snapshot_uuid());
      }
    }
    // uint64 snapshot_id = 3 [deprecated = true];
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (this_._internal_snapshot_id() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_snapshot_id());
      }
    }
    // uint64 sequence_id = 4 [deprecated = true];
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_sequence_id() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_sequence_id());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void SendAlarmSnapshot::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<SendAlarmSnapshot*>(&to_msg);
  auto& from = static_cast<const SendAlarmSnapshot&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:alarms.v1.SendAlarmSnapshot)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_node_id().empty()) {
        _this->_internal_set_node_id(from._internal_node_id());
      } else {
        if (_this->_impl_.node_id_.IsDefault()) {
          _this->_internal_set_node_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_claim_id().empty()) {
        _this->_internal_set_claim_id(from._internal_claim_id());
      } else {
        if (_this->_impl_.claim_id_.IsDefault()) {
          _this->_internal_set_claim_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!from._internal_snapshot_uuid().empty()) {
        _this->_internal_set_snapshot_uuid(from._internal_snapshot_uuid());
      } else {
        if (_this->_impl_.snapshot_uuid_.IsDefault()) {
          _this->_internal_set_snapshot_uuid("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (from._internal_snapshot_id() != 0) {
        _this->_impl_.snapshot_id_ = from._impl_.snapshot_id_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_sequence_id() != 0) {
        _this->_impl_.sequence_id_ = from._impl_.sequence_id_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void SendAlarmSnapshot::CopyFrom(const SendAlarmSnapshot& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:alarms.v1.SendAlarmSnapshot)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void SendAlarmSnapshot::InternalSwap(SendAlarmSnapshot* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.node_id_, &other->_impl_.node_id_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.claim_id_, &other->_impl_.claim_id_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.snapshot_uuid_, &other->_impl_.snapshot_uuid_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(SendAlarmSnapshot, _impl_.sequence_id_)
      + sizeof(SendAlarmSnapshot::_impl_.sequence_id_)
      - PROTOBUF_FIELD_OFFSET(SendAlarmSnapshot, _impl_.snapshot_id_)>(
          reinterpret_cast<char*>(&_impl_.snapshot_id_),
          reinterpret_cast<char*>(&other->_impl_.snapshot_id_));
}

::google::protobuf::Metadata SendAlarmSnapshot::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

AlarmSnapshot::AlarmSnapshot(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, AlarmSnapshot_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:alarms.v1.AlarmSnapshot)
}
PROTOBUF_NDEBUG_INLINE AlarmSnapshot::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::alarms::v1::AlarmSnapshot& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        alarms_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::alarms::v1::AlarmSnapshot,
              PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmSnapshot, _impl_.alarms_)>()
          , from.alarms_
        }
        ,
        node_id_(arena, from.node_id_),
        claim_id_(arena, from.claim_id_),
        snapshot_uuid_(arena, from.snapshot_uuid_) {}

AlarmSnapshot::AlarmSnapshot(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const AlarmSnapshot& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, AlarmSnapshot_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  AlarmSnapshot* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, snapshot_id_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, snapshot_id_),
           offsetof(Impl_, chunk_) -
               offsetof(Impl_, snapshot_id_) +
               sizeof(Impl_::chunk_));

  // @@protoc_insertion_point(copy_constructor:alarms.v1.AlarmSnapshot)
}
PROTOBUF_NDEBUG_INLINE AlarmSnapshot::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        alarms_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::alarms::v1::AlarmSnapshot,
            PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmSnapshot, _impl_.alarms_)>()
         }
        ,
        node_id_(arena),
        claim_id_(arena),
        snapshot_uuid_(arena) {}

inline void AlarmSnapshot::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, snapshot_id_),
           0,
           offsetof(Impl_, chunk_) -
               offsetof(Impl_, snapshot_id_) +
               sizeof(Impl_::chunk_));
}
AlarmSnapshot::~AlarmSnapshot() {
  // @@protoc_insertion_point(destructor:alarms.v1.AlarmSnapshot)
  SharedDtor(*this);
}
inline void AlarmSnapshot::SharedDtor(MessageLite& self) {
  AlarmSnapshot& this_ = static_cast<AlarmSnapshot&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.node_id_.Destroy();
  this_._impl_.claim_id_.Destroy();
  this_._impl_.snapshot_uuid_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull AlarmSnapshot_class_data_ =
        AlarmSnapshot::InternalGenerateClassData_(AlarmSnapshot_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
AlarmSnapshot::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&AlarmSnapshot_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(AlarmSnapshot_class_data_.tc_table);
  return AlarmSnapshot_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
AlarmSnapshot::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&AlarmSnapshot_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&AlarmSnapshot_globals_));
  return AlarmSnapshot_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const AlarmSnapshot::ParseTableT_
    AlarmSnapshot::_table_ =
        AlarmSnapshot::InternalGenerateParseTable_(AlarmSnapshot_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void AlarmSnapshot::Clear() {
// @@protoc_insertion_point(message_clear_start:alarms.v1.AlarmSnapshot)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.alarms_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.node_id_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.claim_id_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _impl_.snapshot_uuid_.ClearNonDefaultToEmpty();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x000000f0U)) {
    ::memset(&_impl_.snapshot_id_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.chunk_) -
        reinterpret_cast<char*>(&_impl_.snapshot_id_)) + sizeof(_impl_.chunk_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL AlarmSnapshot::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const AlarmSnapshot& this_ = static_cast<const AlarmSnapshot&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL AlarmSnapshot::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const AlarmSnapshot& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:alarms.v1.AlarmSnapshot)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string node_id = 1;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_node_id().empty()) {
      const ::std::string& _s = this_._internal_node_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmSnapshot.node_id");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // string claim_id = 2;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (!this_._internal_claim_id().empty()) {
      const ::std::string& _s = this_._internal_claim_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmSnapshot.claim_id");
      target = stream->WriteStringMaybeAliased(2, _s, target);
    }
  }

  // uint64 snapshot_id = 3 [deprecated = true];
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (this_._internal_snapshot_id() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt64ToArray(
          3, this_._internal_snapshot_id(), target);
    }
  }

  // uint32 chunks = 4;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_chunks() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
          4, this_._internal_chunks(), target);
    }
  }

  // uint32 chunk_size = 5;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_chunk_size() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
          5, this_._internal_chunk_size(), target);
    }
  }

  // uint32 chunk = 6;
  if (CheckHasBit(cached_has_bits, 0x00000080U)) {
    if (this_._internal_chunk() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
          6, this_._internal_chunk(), target);
    }
  }

  // repeated .alarms.v1.AlarmLogEntry alarms = 7;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_alarms_size());
         i < n; i++) {
      const auto& repfield = this_._internal_alarms().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              7, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  // string snapshot_uuid = 8;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (!this_._internal_snapshot_uuid().empty()) {
      const ::std::string& _s = this_._internal_snapshot_uuid();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmSnapshot.snapshot_uuid");
      target = stream->WriteStringMaybeAliased(8, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:alarms.v1.AlarmSnapshot)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t AlarmSnapshot::ByteSizeLong(const MessageLite& base) {
  const AlarmSnapshot& this_ = static_cast<const AlarmSnapshot&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t AlarmSnapshot::ByteSizeLong() const {
  const AlarmSnapshot& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:alarms.v1.AlarmSnapshot)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    // repeated .alarms.v1.AlarmLogEntry alarms = 7;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1UL * this_._internal_alarms_size();
      for (const auto& msg : this_._internal_alarms()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
    // string node_id = 1;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_node_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_node_id());
      }
    }
    // string claim_id = 2;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!this_._internal_claim_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_claim_id());
      }
    }
    // string snapshot_uuid = 8;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!this_._internal_snapshot_uuid().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_snapshot_uuid());
      }
    }
    // uint64 snapshot_id = 3 [deprecated = true];
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (this_._internal_snapshot_id() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt64SizePlusOne(
            this_._internal_snapshot_id());
      }
    }
    // uint32 chunks = 4;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_chunks() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
            this_._internal_chunks());
      }
    }
    // uint32 chunk_size = 5;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_chunk_size() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
            this_._internal_chunk_size());
      }
    }
    // uint32 chunk = 6;
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (this_._internal_chunk() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
            this_._internal_chunk());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void AlarmSnapshot::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<AlarmSnapshot*>(&to_msg);
  auto& from = static_cast<const AlarmSnapshot&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:alarms.v1.AlarmSnapshot)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_mutable_alarms()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_alarms());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_node_id().empty()) {
        _this->_internal_set_node_id(from._internal_node_id());
      } else {
        if (_this->_impl_.node_id_.IsDefault()) {
          _this->_internal_set_node_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!from._internal_claim_id().empty()) {
        _this->_internal_set_claim_id(from._internal_claim_id());
      } else {
        if (_this->_impl_.claim_id_.IsDefault()) {
          _this->_internal_set_claim_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!from._internal_snapshot_uuid().empty()) {
        _this->_internal_set_snapshot_uuid(from._internal_snapshot_uuid());
      } else {
        if (_this->_impl_.snapshot_uuid_.IsDefault()) {
          _this->_internal_set_snapshot_uuid("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (from._internal_snapshot_id() != 0) {
        _this->_impl_.snapshot_id_ = from._impl_.snapshot_id_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_chunks() != 0) {
        _this->_impl_.chunks_ = from._impl_.chunks_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_chunk_size() != 0) {
        _this->_impl_.chunk_size_ = from._impl_.chunk_size_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (from._internal_chunk() != 0) {
        _this->_impl_.chunk_ = from._impl_.chunk_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void AlarmSnapshot::CopyFrom(const AlarmSnapshot& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:alarms.v1.AlarmSnapshot)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void AlarmSnapshot::InternalSwap(AlarmSnapshot* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.alarms_.InternalSwap(&other->_impl_.alarms_);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.node_id_, &other->_impl_.node_id_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.claim_id_, &other->_impl_.claim_id_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.snapshot_uuid_, &other->_impl_.snapshot_uuid_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(AlarmSnapshot, _impl_.chunk_)
      + sizeof(AlarmSnapshot::_impl_.chunk_)
      - PROTOBUF_FIELD_OFFSET(AlarmSnapshot, _impl_.snapshot_id_)>(
          reinterpret_cast<char*>(&_impl_.snapshot_id_),
          reinterpret_cast<char*>(&other->_impl_.snapshot_id_));
}

::google::protobuf::Metadata AlarmSnapshot::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// @@protoc_insertion_point(namespace_scope)
}  // namespace v1
}  // namespace alarms
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google
// @@protoc_insertion_point(global_scope)
PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 static ::std::false_type
    _static_init2_ [[maybe_unused]] =
        (::_pbi::AddDescriptors(&descriptor_table_proto_2falarm_2fv1_2fstream_2eproto),
         ::std::false_type{});
#include "google/protobuf/port_undef.inc"
